import { login, LOGIN_DIFF } from 'src/common/utils/login'
import { sendCode, register, saveFormAndPrePay } from './api'
import { API_ADPTER } from 'src/common/adapters/index'
import goHome from 'src/common/utils/goHome'
import { setUserInfoSync } from 'src/common/utils/commonApi'
import { SCENARIO_ID } from 'src/common/constants/scenarioId'

const app = getApp()

Page({
  name: '注册',
  data: {
    step: 1,
    stepTitle: '输入手机号码',
    tipTitle: '如该手机号未注册，将直接为您创建达达账号',
    phoneFoucs: false,
    codeError: false,
    showTimer: false,
    phoneValidate: false,
    codeValidate: false,
    phone: '',
    currentCursor: 0,
    validateCode: '',
    userInfo: {},
    formId: '',
  },

  onShow: function () {
    // diff
    LOGIN_DIFF.getWxInfo().then(res => {
      this.setData({
        userInfo: res,
        phoneFoucs: true,
      })
    })
  },

  confirmPhone() {
    if (!this.data.phoneValidate) return false
    this.sendValidateCode()
  },

  setPhone(e) {
    let cursor = e.detail.cursor
    let reg = /^1[3|4|5|6|7|8][0-9]\d{8}$/
    let tempPhone = e.detail.value
    let trimPhone = tempPhone.replace(/[ ]/g, '').toString()
    let lastPhone = this.data.phone

    if (cursor > this.data.currentCursor) {
      if (trimPhone.length === 3 || trimPhone.length === 7) {
        tempPhone += ' '
        cursor += 1
      } else if (
        (tempPhone.length === 4 && lastPhone.length === 3) ||
        (tempPhone.length === 9 && lastPhone.length === 7)
      ) {
        tempPhone = tempPhone.slice(0, -1) + ' ' + tempPhone.slice(-1)
        cursor += 1
      }
    } else {
      if (trimPhone.length === 3 || trimPhone.length === 7) {
        tempPhone = tempPhone.toString().trim()
        cursor -= 1
      }
    }

    this.setData({
      phoneValidate: reg.test(trimPhone),
      phone: trimPhone,
      currentCursor: cursor,
    })

    return {
      value: tempPhone,
    }
  },

  setValidateCode(e) {
    if (e.detail.value.length < 4) {
      this.setData({
        codeValidate: false,
      })
    } else {
      this.setData({
        validateCode: e.detail.value,
        codeValidate: true,
      })
    }
  },

  sendValidateCode() {
    clearInterval(this.data.timer)

    // 刷新localsession
    LOGIN_DIFF.getNewLocalSession(app).then(() => {
      LOGIN_DIFF.getWxInfo().then(res => {
        this.setData({
          userInfo: res,
        })
      })

      const params = {
        phone: this.data.phone,
        type: 1,
        localSession: API_ADPTER.getStorageSync('LOCAL_SESSION'),
      }

      sendCode(params).then(res => {
        if (res.status === 'success') {
          API_ADPTER.showToast({
            title: '验证码已发送',
            icon: 'success',
          })

          this.setData({
            step: 2,
            stepTitle: `验证码发送至 ${this.data.phone}`,
          })

          this.changeTimerShow()
        }
      })
    })
  },

  goBack() {
    this.setData({
      step: 1,
      stepTitle: '输入手机号码',
      showTimer: false,
      phone: '',
      phoneValidate: false,
    })
  },

  changeTimerShow() {
    this.setData({
      showTimer: !this.data.showTimer,
    })
  },

  confirmBind() {
    let { phone, validateCode } = this.data

    this.setData({
      canClick: false,
    })

    let params = {
      phone,
      validateCode,
      localSession: wx.getStorageSync('LOCAL_SESSION'),
      appletType: app.globalData.isBwm ? 'BWM' : 'DADA',
      encryptedData: this.data.userInfo.encryptedData,
      iv: this.data.userInfo.iv,
    }

    register(params)
      .then(res => {
        this.setData({
          canClick: true,
        })

        if (res.status === 'success') {
          setUserInfoSync(res.content)
          saveFormAndPrePay({
            formId: this.data.formId,
            scenarioId: SCENARIO_ID.login,
            appName: app.globalData.isBwm ? 'BWM' : 'DADA',
          })

          wx.navigateBack()
        } else {
          this.setData({
            stepTitle: `${res.errMsg}，请重新输入`,
            codeError: true,
          })
        }
      })
      .catch(err => {
        if (err.errMsg === '第三方账号已注册过，请直接登陆！') {
          login(app)
            .then(goHome)
            .catch(goHome)
        }
      })
  },

  handleSubmit(e) {
    this.setData({
      formId: e.detail.formId,
    })
  },

})
