import {
  getUserInfoSync,
  removeUserInfoSync,
  setUserInfoSync,
  login as apiLogin,
  get3rdSession as apiGet3rdSession,
} from './commonApi'
import track from 'track-mini-program'
import { API_ADPTER } from 'src/common/adapters/index'

/*******************内部引用--START***********************/

const setTrackInfo = () => {
  track.setUser({
    userId: API_ADPTER.getStorageSync('UID') || '',
  })
  track.setDeviceId({
    deviceId: API_ADPTER.getStorageSync('OPEN_VALUE') || '',
  })
}

const loginPromise = () => {
  return new Promise((resolve, reject) => {
    API_ADPTER.login({
      success: res => {
        resolve(res)
      },
      fail: res => {
        reject(res)
      },
    })
  })
}

const wxGetUserInfo = (resolve, reject) => {
  API_ADPTER.getUserInfo({
    withCredentials: true,
    success: res => {
      let userInfo = {
        ...res.userInfo,
        encryptedData: res.encryptedData || res.data,
        iv: res.iv,
      }

      API_ADPTER.setStorageSync('WX_USER_INFO', userInfo)
      resolve(userInfo)
    },
    fail: () => {
      reject()
    },
  })
}

const get3rdSession = (app, code) => {
  return apiGet3rdSession(app, {
    code: code,
    appletType: app.globalData.isBwm ? 'BWM' : 'DADA',
  })
    .then(res => {
      API_ADPTER.setStorageSync('LOCAL_SESSION', res.content.localSession)
      API_ADPTER.setStorageSync('OPEN_VALUE', res.content.openValue)
      API_ADPTER.setStorageSync('OPEN_DIGEST', res.content.openDigest)
      setTrackInfo()
      if (!res.content.hasUnionId) {
        return getWxInfo()
          .then(() => res.content.localSession)
          .catch(() => {
            return res.content.localSession
          })
      }
      return res.content.localSession
    })
    .catch(res => {
      removeUserInfoSync()
      return Promise.reject(res)
    })
}

// 登陆--根据session获取用户信息
const getUserBySession = (app, session, isJump, isActivity) => {
  const userInfo = API_ADPTER.getStorageSync('WX_USER_INFO')
  const { encryptedData = '', iv = '' } = userInfo

  let params = {
    localSession: session,
    appletType: app.globalData.isBwm ? 'BWM' : 'DADA',
    encryptedData,
    iv,
  }

  return apiLogin(app, params)
    .then(rep => {
      if (isActivity) {
        activityCallback(app, rep)
      } else {
        const loginData = mainCallback(app, isJump, rep)

        if (loginData && loginData.isError) {
          return Promise.reject(loginData.rep)
        }
      }
    })
    .catch(res => {
      removeUserInfoSync()
      return Promise.reject(res)
    })
}

// 活动登陆回调
const activityCallback = (app, rep) => {
  if (rep.status === 'success') {
    setUserInfoSync(rep.content)
    app.globalData.activityBaseInfo.loggedIn = true
    app.globalData.activityBaseInfo.phone = rep.content.phone
  }
}

// 主流程登陆回调
const mainCallback = (app, isJump, rep) => {
  if (rep.status === 'success') {
    setUserInfoSync(rep.content)
  } else {
    if (rep.errCode === 6120 && isJump && !app.globalData.isBwm) {
      API_ADPTER.navigateTo({
        url: '/common/pages/login/index',
      })
    }

    return {
      isError: true,
      rep,
    }
  }

  return getUserInfoSync()
}

/*******************内部引用--END***********************/



/*******************导出--START***********************/

// for 外层api调用
// 微信同其他平台 登陆回调不同处理
export const loginDiff = (app, isJump, isActivity) => {
  const data = getUserInfoSync()

  if (app.globalData.shouldFetchLogin) {
    return loginPromise()
      .then(res => {
        return get3rdSession(app, res.code)
      })
      .then(session => {
        app.globalData.shouldFetchLogin = false

        return getUserBySession(app, session, isJump, isActivity)
      })
      .then(setTrackInfo)
  }

  if (data.token) {
    setTrackInfo()
    app.globalData.activityBaseInfo.loggedIn = true
    app.globalData.activityBaseInfo.phone = data.phone
    return Promise.resolve(data)
  }

  return Promise.reject(data)
}

// for 各业务调用
export const getNewLocalSession = app => {
  return loginPromise().then(res => {
    return get3rdSession(app, res.code)
  })
}

// for 各业务调用
export const getWxInfo = () => {
  return new Promise((resolve, reject) => {
    API_ADPTER.getSetting({
      success: res => {
        if (!res.authSetting['scope.userInfo']) {
          API_ADPTER.authorize({
            scope: 'scope.userInfo',
            success: () => {
              wxGetUserInfo(resolve, reject)
            },
            fail: () => {
              reject(new Error('getWxInfo failed'))
            },
          })
        } else {
          wxGetUserInfo(resolve, reject)
        }
      },
      fail: () => {
        reject(new Error('getWxInfo failed'))
      },
    })
  })
}

/*******************导出--END***********************/
