import { login, LOGIN_DIFF } from 'src/common/utils/login'
import { getBargainOrderDetail, cutBargainOrder } from './api'
import dayjs from 'dayjs'
import track from 'track-mini-program'
import { navigateTo } from 'src/common/utils/navigate'
import { saveFormAndPrePay } from 'src/common/pages/login/api'
import { SCENARIO_ID } from 'src/common/constants/scenarioId'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

const btnTextMap = {
  CUT_SUCCESS: '砍价成功，查看奖励',
  CUT_FAILED: '砍价失败，再来一单',
  GO_ORDER_DETAIL: '查看订单状态',
  SHARE: '邀请好友帮砍价',
  SHARE_CUT: '分享给好友，可再砍一刀',
  CUT: '砍一刀',
  HELP_CUT: '帮他砍一刀',
  GO_ADD_ORDER: '我也下一单',
  DEFAULT: '没有匹配文案',
}

const cutStatusMap = {
  1: 'PROCESSING',
  2: 'PROCESSING',
  3: 'SUCCESS',
  10: 'FAILED',
}

Page({
  data: {
    // instanceCode: '',
    showModalType: '',
    cutpriceInstance: {
      targetValue: 0,
      cutValue: 0,
      cutRate: 0,
    },
    cutRecs: [],
    btnText: '',
    btnTextType: '',
    cutValue: 0,
    cumulativeCutValue: 0,
    autoSharedCut: false,
  },
  onShareAppMessage() {
    const nickName = API_ADPTER.getStorageSync('WX_USER_INFO').nickName
    const params = {
      title: `江湖救急！！！「${
        nickName === undefined ? '您的好友' : nickName
      }」邀请你拔刀相助，帮砍1刀！`,
      imageUrl:
        'https://fe.imdada.cn/mini-program/images/activity/bargain/cut-price-share.png',
      path: `/common/pages/activity/bargain/detail/index?instanceCode=${
        app.globalData.activityBaseInfo.instanceCode
      }&channel=DADA_mini_program_cut_price`,
    }

    if (this.data.btnTextType === 'SHARE_CUT') {
      track.manuallyTrack({ clickId: 'ClickShareFriend' })
      this.setData({ autoSharedCut: true })
    } else {
      track.manuallyTrack({ clickId: 'ClickInviteFriend' })
    }

    return params
  },
  onLoad(options) {
    // this.setData({
    //   instanceCode: options.instanceCode,
    // })
    app.globalData.activityBaseInfo.instanceCode = options.instanceCode
  },
  onShow() {
    this.initLogin()
    if (this.data.autoSharedCut) {
      this.setData({ autoSharedCut: false })
      this.cutBargainOrder().then(() => {
        this.toggleModal('sharedCut')
      })
    }
  },
  registSuccess(e) {
    this.toggleModal('login')
    this.cutBargainOrder().then(() => {
      this.toggleModal('loggedHelpCut')
    })
  },
  registFail(e) {
    const res = e.detail.res

    API_ADPTER.showToast({
      title: res.errMsg + '，请重新输入',
      icon: 'none',
    })
  },
  initLogin() {
    login(app)
      .then(data => {
        // 登录成功
        LOGIN_DIFF.getWxInfo()
          .then(() => {
            if (!API_ADPTER.getStorageSync('TOKEN')) {
              this.getBargainOrderDetail()
            } else {
              this.getBargainOrderDetail().then(() => {
                if (this.getBtnTextType() === 'CUT') {
                  this.cutBargainOrder().then(() =>
                    this.toggleModal('normalCut')
                  )
                }
              })
            }
          })
          .catch(() => {
            this.getBargainOrderDetail()
          })
      })
      .catch(() => {
        // 登录失败
        LOGIN_DIFF.getWxInfo()
          .then(() => {
            this.getBargainOrderDetail()
          })
          .catch(() => {
            this.getBargainOrderDetail()
          })
      })
  },
  getAuthorization({ detail: e }) {
    if (e.detail.errMsg !== 'getUserInfo:ok') return
    LOGIN_DIFF.getWxInfo().then(() => {
      this.getBargainOrderDetail().then(() => {
        this.cutBargainOrder().then(() => {
          this.toggleModal('normalCut')
        })
      })
    })
  },
  helpCut({ detail: e }) {
    track.manuallyTrack({ clickId: 'ClickHelpCutDown' })
    if (e.detail.errMsg !== 'getUserInfo:ok') return
    LOGIN_DIFF.getWxInfo().then(() => {
      const { login } = this.data.cutpriceInstance

      if (login) {
        this.cutBargainOrder().then(() => {
          this.toggleModal('normalCut')
        })
      } else {
        this.toggleModal('login')
      }
    })
  },
  getBtnTextType() {
    // 是否登录、是否是自己的砍价单、砍价状态、砍价金额是否已满、已砍了几刀
    const {
      login,
      orderId,
      status,
      targetValue,
      cutValue,
      cutCount,
    } = this.data.cutpriceInstance
    const fullAmount = targetValue === cutValue
    const statusDesc = cutStatusMap[status]
    if (login && orderId) {
      if (statusDesc === 'SUCCESS') return 'CUT_SUCCESS'
      if (statusDesc === 'FAILED') return 'CUT_FAILED'
      if (statusDesc === 'PROCESSING' && fullAmount) return 'GO_ORDER_DETAIL'
      if (statusDesc === 'PROCESSING' && !fullAmount && cutCount === 2) {
        return 'SHARE'
      }
      if (statusDesc === 'PROCESSING' && !fullAmount && cutCount === 1) {
        return 'SHARE_CUT'
      }
      return 'CUT'
    }
    if (login && !orderId) {
      if (statusDesc === 'PROCESSING' && cutCount === 0 && !fullAmount) {
        return 'HELP_CUT'
      }
      return 'GO_ADD_ORDER'
    }
    if (!login) {
      if (statusDesc === 'PROCESSING' && cutCount === 0 && !fullAmount) {
        return 'HELP_CUT'
      }
      return 'GO_ADD_ORDER'
    }
    return 'DEFAULT'
  },
  getBargainOrderDetail() {
    const openDigest = API_ADPTER.getStorageSync('OPEN_DIGEST')
    // const { instanceCode } = this.data
    const instanceCode = app.globalData.activityBaseInfo.instanceCode

    return getBargainOrderDetail({ openDigest, instanceCode }).then(res => {
      const { cutValue, targetValue } = res.cutpriceInstance
      this.setData({
        cutpriceInstance: {
          ...res.cutpriceInstance,
          cutRate: cutValue / targetValue,
          lastValue:
            targetValue - cutValue > 0
              ? (targetValue - cutValue).toFixed(2)
              : 0,
        },
        cutRecs: res.cutRecs.map(item => ({
          ...item,
          timeDesc: dayjs(item.createTime * 1000).format('YYYY-M-D HH:mm'),
        })),
      })
      const btnTextType = this.getBtnTextType()
      this.setData({ btnText: btnTextMap[btnTextType], btnTextType })
    })
  },
  cutBargainOrder() {
    // const { instanceCode } = this.data
    const instanceCode = app.globalData.activityBaseInfo.instanceCode
    const { nickName: name, avatarUrl: avatar } = API_ADPTER.getStorageSync(
      'WX_USER_INFO'
    )
    const openDigest = API_ADPTER.getStorageSync('OPEN_DIGEST')

    return cutBargainOrder({
      instanceCode,
      openDigest,
      name,
      avatar,
    }).then(res => {
      this.setData({
        cumulativeCutValue: res.cumulativeCutValue,
        cutValue: res.cutValue,
      })
      this.getBargainOrderDetail()
    })
  },
  toggleModal(params) {
    const type =
      typeof params === 'string' ? params : params.currentTarget.dataset.type

    this.setData({
      showModalType: this.data.showModalType === type ? '' : type,
    })
  },
  goBargainList() {
    navigateTo({ url: '/common/pages/activity/bargain/list/index' })
  },
  goAddOrder() {
    navigateTo({ url: '/pages/index/index' })
  },
  goOrderDetail() {
    const { orderId } = this.data.cutpriceInstance

    app.globalData.orderDetailInfo.activeOrderId = orderId
    navigateTo({ url: '/common/pages/orderDetail/index' })
  },
  goLogin() {
    track.manuallyTrack({ clickId: 'ClickToLogin' })
    this.toggleModal('login')
  },
  handleSubmit(e) {
    const formId = e.detail.formId
    const { orderId } = this.data.cutpriceInstance

    if (!orderId) return

    saveFormAndPrePay({
      formId,
      scenarioId: SCENARIO_ID.bargin,
      appName: 'DADA',
    })
  },

})
