import { sendCode, register, saveFormAndPrePay } from 'src/common/pages/login/api'
import { getNewLocalSession } from 'src/common/utils/login'
import { setUserInfoSync } from 'src/common/utils/commonApi'
import { SCENARIO_ID } from 'src/common/constants/scenarioId'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Component({
  properties: {
    channelCode: {
      type: String,
      value: 'tongyonghuodong',
    },
  },

  data: {
    codeBtnDisabled: true, // 发送按钮不可点击
    loginBtnDisabled: true, // 登陆按钮不可点击
    sent: false, // 发送验证码
    phone: '',
    code: '',
    phoneValid: false, // 有效电话号码
    codeValid: false, // 有效验证码
    showTimer: false,
    formId: '',
  },

  methods: {
    setValidatePhone(e) {
      const phone = this.trim(e.detail.value)
      const phoneValid = /^1[3|4|5|7|8][0-9]\d{8}$/.test(phone)

      this.setData({
        phoneValid: phoneValid,
        codeBtnDisabled: !phoneValid,
        phone: phoneValid ? phone : '',
      })
    },

    setValidateCode(e) {
      const code = this.trim(e.detail.value)
      const codeValid = /^\d{4}$/.test(code)

      this.setData({
        code: code,
        codeValid: codeValid,
        loginBtnDisabled: !codeValid || !this.data.phoneValid,
      })

      app.globalData.activityBaseInfo.phone = this.phone
    },

    sendValidateCode() {
      return getNewLocalSession(app).then(() => {
        let params = {
          phone: this.data.phone,
          type: 1,
          localSession: API_ADPTER.getStorageSync('LOCAL_SESSION'),
        }

        return sendCode(params).then(res => {
          if (res.status === 'success') {
            API_ADPTER.showToast({
              title: '验证码已发送',
              icon: 'success',
            })

            this.changeTimerShow()
          }
        })
      })
    },

    changeTimerShow() {
      this.setData({
        showTimer: !this.data.showTimer,
        sent: !this.data.sent,
        codeBtnDisabled: !this.data.codeBtnDisabled,
      })
    },

    trim(val) {
      return val.replace(/\s+/g, '')
    },

    register() {
      const formId = this.data.formId
      const registerParams = {
        phone: this.data.phone,
        validateCode: this.data.code,
        localSession: API_ADPTER.getStorageSync('LOCAL_SESSION'),
        appletType: 'DADA',
        channelCode: this.properties.channelCode,
        formId,
      }

      return register(registerParams, {toast: false}).then(res => {
        setUserInfoSync(res.content)
        app.globalData.activityBaseInfo.loggedIn = true
        saveFormAndPrePay({
          formId,
          scenarioId: SCENARIO_ID.login,
          appName: 'DADA',
        })

        return res
      })
    },

    handleSubmit(e) {
      this.setData({
        formId: e.detail.formId,
      })
    },
  },
})
