import { updateSender, updateReceiver, addSender, addReceiver, getIntelligentFillingInfo } from './api'
import { getPoiByKeyword } from 'src/common/utils/map'
import { getUuid } from 'src/common/utils/uuid'
import track from 'track-mini-program'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  name: '地址编辑',
  data: {
    addrInfo: null,
    intelligentFillingStr: '',
    cliboardInfo: '',
    addressSearchStatus: 'noSearch', // noSearch-无搜索, isSearching-搜索中, searchOver-搜索结束, searchWithoutResult-搜索无结果
    searchPoiList: null,
    searchFrom: 'history', // poi-定位地址, history-匹配常用地址, search-智能搜索地址
    isTEL: false,
    phonePlaceholder: '手机号码',
    type: '',
    hasCliboardInfo: false,
    intelligentResult: null,
    title: '完善地址信息',
  },
  onShow: function () {
    let {
      edit, type,
    } = app.globalData.commonAddress

    this.initCliboardData()

    // 寄件人 无常用地址 才走定位逻辑(从搜索页回来，不走定位逻辑)
    if (this.data.searchFrom !== 'search' && edit.poiName === '' && type === 'sender') {
      this.initAddress()
    }

    edit = app.globalData.commonAddress.edit

    this.setData({
      addrInfo: {
        ...edit,
      },
      type,
      isTEL: this.checkTEL(edit.phone),
    })
  },
  onReady: function () {
    const {
      title = '完善地址信息',
    } = app.globalData.commonAddress

    this.name = title
    this.setData({ title })
    API_ADPTER.setNavigationBarTitle({ title })
  },
  initAddress: function () {
    const { poiList } = app.globalData.commonAddress

    if (poiList && poiList.length > 0) {
      this.setSearchFrom('poi')
      this.setIsPoi(true)

      const poiInfo = poiList[0]

      app.globalData.commonAddress.edit = {
        ...app.globalData.commonAddress.edit,
        ...poiInfo,
      }
    } else {
      this.setIsPoi(false)
    }
  },

  initCliboardData: function () {
    if (this.data.cliboardInfo !== '') {
      return
    }
    const that = this

    API_ADPTER.getClipboardData({
      success(res) {
        const cliboardInfo = res.data

        if (cliboardInfo !== '') {
          that.setData({
            cliboardInfo,
          })
          that.getIntelligentFillingInfo('cliboard')
        }
      },
    })
  },

  setCliboardData: function (result) {
    const { poi, phone } = result

    if (poi && phone) {
      this.setData({
        intelligentResult: result,
      })
      this.toggleCliboard()
    }
  },

  submitIntelligentFillingInfo: function (e) {
    if (!this.data.intelligentFillingStr) {
      API_ADPTER.showToast({
        title: '请先粘贴发货信息',
        icon: 'none',
      })
      return
    }
    this.trackClick(e)
    this.getIntelligentFillingInfo('submit')
  },
  getIntelligentFillingInfo: function (searchType) {
    const cityName = app.globalData.commonAddress.location.city
    const address = this.data.intelligentFillingStr || this.data.cliboardInfo
    const params = {
      'cityName': cityName.substring(0, cityName.length - 1),
      requestId: getUuid('CRINUM_REQUEST_UUID'),
      address,
    }
    let options = { toast: false }

    if (searchType === 'submit') {
      this.setSearchStatus('isSearching')
      this.setIsPoi(false)
      options = { toast: true }
    }

    getIntelligentFillingInfo(params, options).then(res => {
      if (searchType === 'submit') {
        this.getPoiByKeyworNew(res)
      } else {
        this.setCliboardData(res)
      }
    }).catch(e => {
      this.setSearchStatus('searchWithoutResult')
    })
  },
  setAddrInfo: function (reult) {
    const isTEL = reult.phoneType === 'tel'

    this.setData({
      addrInfo: {
        ...this.data.addrInfo,
        name: reult.name,
        phone: reult.phone,
        doorplate: reult.number,
        poiAddress: '',
        poiName: '',
      },
      isTEL,
    })

    this.setEditInfo()
  },
  getPoiByKeyworNew: function (result) {
    const keyword = result.poi

    this.setAddrInfo(result)
    // 默认搜索关键词/搜索状态
    app.globalData.commonAddress.keyword = ''

    if (result.poi !== '') {
      const params = {
        keyword,
        'city': app.globalData.commonAddress.location.city,
        location: app.globalData.commonAddress.location,
      }

      getPoiByKeyword(params).then(res => {
        if (res && res.length > 0) {
          app.globalData.commonAddress.keyword = keyword

          this.setData({
            searchPoiList: res,
          })

          this.setEditInfo()

          this.setSearchStatus('searchOver')
        } else {
          this.setSearchStatus('searchWithoutResult')
        }
      })
    } else {
      this.setSearchStatus('searchWithoutResult')
    }

    this.setSearchFrom('search')
  },
  chooseAddress: function (e) {
    const poiData = e.currentTarget.dataset.item

    this.setIsPoi(false)
    this.setSearchStatus('noSearch')

    this.setData({
      addrInfo: {
        ...this.data.addrInfo,
        ...poiData,
      },
    })

    app.globalData.commonAddress.keyword = poiData.poiName
    this.setEditInfo()
  },
  goAddrPoiList: function () {
    this.setSearchStatus('noSearch')
    API_ADPTER.navigateTo({
      url: `/common/pages/addrPoiList/index?searchFrom=${this.data.searchFrom}`,
    })
  },
  saveAddrInfo: function () {
    const { addrInfo } = this.data
    const type = app.globalData.commonAddress.type
    const that = this
    const { poiName, name, phone } = addrInfo

    if (this.checkEmpty(poiName)) {
      this.showCheckMsg('请填写地址信息')
      return
    } else if (this.checkEmpty(name)) {
      this.showCheckMsg('请填写联系人姓名')
      return
    } else if (this.checkEmpty(phone)) {
      this.showCheckMsg('请填写电话号码')
      return
    }

    if (addrInfo.id) {
      // 编辑
      if (type === 'sender') {
        updateSender(this.data.addrInfo).then(res => {
          app.globalData.commonAddress.sender = res
          that.backFrom()
        })
      } else {
        updateReceiver(this.data.addrInfo).then(res => {
          app.globalData.commonAddress.receiver = res
          that.backFrom()
        })
      }
    } else {
      // 新增
      if (type === 'sender') {
        addSender(this.data.addrInfo).then(res => {
          app.globalData.commonAddress.sender = res
          that.backFrom()
        })
      } else {
        addReceiver(this.data.addrInfo).then(res => {
          app.globalData.commonAddress.receiver = res
          that.backFrom()
        })
      }
    }
  },
  backFrom: function () {
    const from = app.globalData.commonAddress.from
    const pages = getCurrentPages()
    let delta = 1

    pages.map((item, index) => {
      if (item.route === from) {
        delta = pages.length - index - 1
      }
    })
    API_ADPTER.navigateBack({
      delta,
    })
  },
  changeAddrInfo: function (e) {
    const val = e.detail.value
    const key = e.currentTarget.dataset.key

    this.setData({
      addrInfo: { ...this.data.addrInfo, [key]: val },
    })

    app.globalData.commonAddress.edit[key] = val
  },
  changeIntelligentFillingStr: function (e) {
    const val = e.detail.value

    this.setData({
      intelligentFillingStr: val,
    })
  },
  clearIntelligentFillingInfo: function (e) {
    this.setData({
      intelligentFillingStr: '',
    })

    this.trackClick(e)
  },
  toggleMobile: function () {
    let phonePlaceholder = ''

    if (this.data.isTEL) {
      phonePlaceholder = '手机号码'
    } else {
      phonePlaceholder = '座机号码'
    }

    this.setData({
      phonePlaceholder,
      isTEL: !this.data.isTEL,
      addrInfo: {
        ...this.data.addrInfo,
        phone: '',
      },
    })

    this.setEditInfo()

    track.manuallyTrack({
      clickId: 'ClickCheckPhoneStatus',
      clickPar: { status: this.data.isTEL ? 'telephone' : 'mobile' },
    })
  },
  toggleCliboard: function () {
    this.setData({
      hasCliboardInfo: !this.data.hasCliboardInfo,
    })
  },
  closeCliboard: function (e) {
    this.toggleCliboard()
    this.trackClick(e)
  },
  useCliboardInfo: function (e) {
    this.setSearchStatus('isSearching')
    this.setIsPoi(false)
    this.getPoiByKeyworNew(this.data.intelligentResult)
    this.toggleCliboard()
    this.trackClick(e)
  },
  setEditInfo: function () {
    app.globalData.commonAddress.edit = {
      ...app.globalData.commonAddress.edit,
      ...this.data.addrInfo,
    }
  },
  setSearchStatus: function (addressSearchStatus) {
    this.setData({
      addressSearchStatus,
    })
  },
  setSearchFrom: function (searchFrom) {
    this.setData({
      searchFrom,
    })
  },
  setIsPoi: function (isPoi) {
    this.setData({
      addrInfo: {
        ...this.data.addrInfo,
        isPoi,
      },
    })

    app.globalData.commonAddress.edit = {
      ...app.globalData.commonAddress.edit,
      isPoi,
    }
  },
  // 是否是座机号
  checkTEL: function (phone) {
    if (phone !== '') {
      return /0\d{2,3}\d{7,8}/.test(phone)
    }

    return false
  },
  trackClick: function (e) {
    const clickId = e.currentTarget.dataset.clickid

    track.manuallyTrack({
      clickId,
    })
  },
  checkEmpty: function (param) {
    return param === ''
  },
  showCheckMsg: function (toastMsg) {
    API_ADPTER.showToast({
      title: toastMsg,
      icon: 'none',
    })
  },
})
