import { post, get } from '../../utils/request'
import { reverseGeocoder } from '../../utils/map'

const getReceiverAddrList = params => {
  return post('client/getSortedReceivers', {
    ...params,
  }).then(res => {
    return res.content
  })
}

const getSenderAddrList = params => {
  return post('client/getSortedSenders', {
    ...params,
  }).then(res => {
    return res.content
  })
}

const addSender = params => {
  if (!params.adCode) {
    return getAdCode({
      lat: params.lat,
      lng: params.lng,
    }).then(adCode => {
      return post('client/addSender', {
        ...params,
        adCode,
      }).then(res => {
        return res.content
      })
    })
  } else {
    return post('client/addSender', {
      ...params,
    }).then(res => {
      return res.content
    })
  }
}

const updateSender = params => {
  return post('client/updateSender', {
    ...params,
  }).then(res => {
    return res.content
  })
}

const delSender = id => post('client/delSender', [{ senderId: id }])

const delReceiver = id => post('client/delReceiver', [{ receiverId: id }])

const updateReceiver = params => {
  return post('client/updateReceiver', {
    ...params,
  }).then(res => {
    return res.content
  })
}

const getBwmShopList = params => {
  return get('bwm/shop/list', {
    ...params,
  }).then(res => {
    return res.content
  })
}

const getBwmRecommendShopList = params => {
  return get('bwm/shop/recommend', {
    ...params,
  }).then(res => {
    return res.content
  })
}

const getAdCode = params => {
  return reverseGeocoder({ lat: params.lat, lng: params.lng }).then(
    res => res.adCode
  )
}

export {
  getSenderAddrList,
  getReceiverAddrList,
  addSender,
  updateSender,
  updateReceiver,
  delSender,
  delReceiver,
  getBwmShopList,
  getBwmRecommendShopList,
}
