import * as api from './api'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

const initPage = {
  count: true,
  endRow: '',
  firstPage: true,
  hasNextPage: false,
  hasPreviousPage: '',
  isCount: '',
  lastPage: true,
  nextPage: '',
  pageNum: 1,
  pageSize: 10,
  pages: '',
  prePage: '',
  size: '',
  startRow: '',
  total: 0,
}

Page({
  name: '常用地址',
  data: {
    addrList: [],
    page: {
      ...initPage,
    },
    title: '常用地址',
  },
  onShow: function () {
    const { type } = app.globalData.commonAddress

    if (type === 'sender') {
      this.name = '常用发货地址'
    } else if (type === 'receiver') {
      this.name = '常用收货地址'
    } else {
      this.name = '常用地址'
    }

    API_ADPTER.setNavigationBarTitle({
      title: this.name,
    })
    this.setData({ title: this.name })
  },
  onLoad: function () {
    this.init()
  },
  init: function () {
    const type = app.globalData.commonAddress.type
    // const keyword = app.globalData.commonAddress.keyword

    this.setData({
      type,
      page: initPage,
    })
    this.getAddrList()
  },
  changeFavourite: function (e) {
    const isFavourite = e.currentTarget.dataset.isFavourite
    const item = e.currentTarget.dataset.item

    if (this.data.type === 'sender') {
      api.updateSender({ ...item, isFavourite }).then(this.init)
      return
    }
    if (this.data.type === 'receiver') {
      api.updateReceiver({ ...item, isFavourite }).then(this.init)
    }
  },
  chooseAddr: function (e) {
    const addr = e.currentTarget.dataset.addr
    const type = app.globalData.commonAddress.type

    if (type === 'sender') {
      app.globalData.commonAddress.sender = addr
    } else {
      app.globalData.commonAddress.receiver = addr
    }

    app.globalData.commonAddress.edit = addr
    this.backFrom()
  },
  backFrom: function () {
    const from = app.globalData.commonAddress.from
    const pages = getCurrentPages()
    let delta = 1

    pages.map((item, index) => {
      if (item.route === from) {
        delta = pages.length - index - 1
      }
    })
    API_ADPTER.navigateBack({
      delta,
    })
  },
  onPullDownRefresh: function () {
    this.setData({
      page: initPage,
    })
    this.getAddrList().then(API_ADPTER.stopPullDownRefresh)
  },
  onReachBottom: function () {
    if (this.data.page.hasNextPage) {
      this.setData({
        'page.pageNum': this.data.page.pageNum + 1,
      })
      this.getAddrList()
    }
  },
  getAddrList() {
    const params = {
      isCount: 1,
      pageNum: this.data.page.pageNum,
      pageSize: this.data.page.pageSize,
    }
    const type = app.globalData.commonAddress.type

    if (type === 'sender') {
      return api.getSenderAddrList(params).then(res => this.setAddrList(res))
    } else {
      return api.getReceiverAddrList(params).then(res => this.setAddrList(res))
    }
  },
  setAddrList(res) {
    const params = {
      isCount: 1,
      pageNum: this.data.page.pageNum,
      pageSize: this.data.page.pageSize,
    }
    let addrList = []
    if (params.pageNum === 1) {
      addrList = [...res.list]
    } else {
      addrList = [...this.data.addrList, ...res.list]
    }
    this.setData({
      addrList,
      page: res.page,
    })
  },
  showDelModal(e) {
    const { id } = e.currentTarget.dataset.addr

    API_ADPTER.showModal({
      title: '删除地址',
      content: '删除该地址后，将无法恢复',
      confirmText: '删除',
      cancelText: '取消',
      confirmColor: '#1287ff',
      success: res => {
        const type = app.globalData.commonAddress.type

        if (res.confirm) {
          if (type === 'sender') {
            api.delSender(id).then(this.init)

            return
          }
          api.delReceiver(id).then(this.init)
        }
      },
    })
  },
})
