import * as api from './api'
import { getPoiByKeyword } from 'src/common/utils/map'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  name: '搜索地址',
  data: {
    type: '',
    keyword: '',
    placeholder: '',
    poiList: [],
    bwmShopList: [],
    bwmRecommendShopList: [],
    searchFrom: '',
    cityName: '',
    title: '',
  },
  onShow: function () {
    const { type } = app.globalData.commonAddress
    const cityName = app.globalData.commonAddress.location.city

    this.name = '搜索地址'
    this.name = `${this.name}_${type}`

    if (`${this.data.cityName}市` !== cityName) {
      this.init()
    }
  },
  onLoad: function (options) {
    const { searchFrom } = options

    this.setData({
      searchFrom,
    })
    this.init()
  },
  onUnload: function () {
    this.setData({
      placeholder: '',
      bwmShopList: [],
      bwmRecommendShopList: [],
    })
  },
  init: function () {
    const type = app.globalData.commonAddress.type
    const keyword = app.globalData.commonAddress.keyword
    let poiList = app.globalData.commonAddress.poiList
    let cityName = app.globalData.commonAddress.location.city
    const searchFrom = this.data.searchFrom

    cityName = cityName.substring(0, cityName.length - 1)

    if (searchFrom === 'search') {
      // this.initEdit()
      if (keyword === '') {
        poiList = []
      } else {
        this.setData({
          keyword,
        })
        this.getPoiByKeyword(keyword)
      }
    } else if (type === 'receiver' || searchFrom === 'history' || type === 'shop') {
      poiList = []
    }

    this.setData({
      type,
      searchFrom,
      poiList,
      cityName,
    })
    let title = ''
    if (type === 'shop') {
      this.setData({
        placeholder: keyword,
      })
      title = '搜索店铺'
      this.getBwmShopList().then(res => {
        if (res.length) return
        this.getPoiByKeyword(keyword)
      })
      this.getBwmRecommendShopList()
    } else if (type === 'purePoi') {
      title = '搜索地址'
      this.getPoiByKeyword(keyword)
    } else {
      title = '搜索地址'
    }
    API_ADPTER.setNavigationBarTitle({ title })
    this.setData({ title })
  },

  initEdit() {
    // 如果不选中地址 默认为空地址
    const poi = {
      adCode: '',
      poiName: '',
      poiAddress: '',
      cityName: '',
      lat: 0,
      lng: 0,
      distance: 0,
    }

    app.globalData.commonAddress.edit = {
      ...app.globalData.commonAddress.edit,
      ...poi,
      isPoi: false,
    }
  },
  // 帮我买指定店铺
  getBwmShopList() {
    const { bwmCardId: cardId, location } = app.globalData.commonAddress
    const { adCode, lat, lng } = location

    if (!lat) return Promise.resolve([])
    return api
      .getBwmShopList({
        cardId,
        adCode,
        lat,
        lng,
      })
      .then(res => {
        this.setData({
          bwmShopList: res,
        })
        return res
      })
  },
  // 帮我买推荐店铺
  getBwmRecommendShopList() {
    const { bwmCardId: cardId, location } = app.globalData.commonAddress
    const { adCode, lat, lng } = location

    if (!lat) return Promise.resolve([])
    return api
      .getBwmRecommendShopList({
        cardId,
        adCode,
        lat,
        lng,
      })
      .then(res => {
        this.setData({
          bwmRecommendShopList: res,
        })
        return res
      })
  },
  changeKeyword: function (e) {
    const keyword = e.detail.value

    this.setData({ keyword })
    this.getPoiByKeyword(keyword)
  },
  clearKeyword: function () {
    this.setData({
      keyword: '',
      poiList: [],
    })
  },
  getPoiByKeyword(keyword) {
    const location = app.globalData.commonAddress.location
    const city = app.globalData.commonAddress.location.city
    const type = app.globalData.commonAddress.type
    let params = { keyword, location, city }

    if (location.lat && (type === 'shop' || type === 'purePoi')) {
      params.preferredDistance = true
    } else {
      params.preferredDistance = false
    }

    if (!keyword.trim()) {
      this.setData({
        poiList: [],
      })
      return
    }
    getPoiByKeyword(params).then(res => {
      this.setData({
        poiList: res,
      })
    })
  },
  choosePoi: function (e) {
    const poi = e.currentTarget.dataset.poi
    const type = this.data.type
    const that = this

    if (type === 'purePoi') {
      app.globalData.commonAddress.purePoi = poi
      this.backFrom()

      return
    }

    if (type === 'shop') {
      app.globalData.orderBillInfo.queueFee = poi.queueFee / 100 || 0
      app.globalData.orderBillInfo.poiId = poi.poiId
      app.globalData.orderBillInfo.shopName = poi.poiName
      api
        .addSender({
          ...poi,
          isHidden: 1,
        })
        .then(res => {
          app.globalData.commonAddress.receiver = res
          that.backFrom()
        })

      return
    }

    app.globalData.commonAddress.keyword = poi.poiName
    app.globalData.commonAddress.edit = {
      ...app.globalData.commonAddress.edit,
      ...poi,
      isPoi: false,
    }

    this.goEdit()
  },
  goEdit: function () {
    const editUrl = 'common/pages/addrEdit/index'
    const pages = getCurrentPages()
    let index = -1

    pages.map((item, i) => {
      if (item.route === editUrl) {
        index = i
      }
    })

    if (index >= 0) {
      API_ADPTER.navigateBack({
        delta: pages.length - index - 1,
      })
    } else {
      API_ADPTER.navigateTo({
        url: `/${editUrl}`,
      })
    }
  },
  backFrom: function () {
    const from = app.globalData.commonAddress.from
    const pages = getCurrentPages()
    let delta = 1

    pages.map((item, index) => {
      if (item.route === from) {
        delta = pages.length - index - 1
      }
    })
    API_ADPTER.navigateBack({
      delta,
    })
  },
  goBack: function () {
    API_ADPTER.navigateBack({
      delta: 1,
    })
  },
  goAddrList: function () {
    app.globalData.commonAddress.from = 'common/pages/addrEdit/index'
    API_ADPTER.navigateTo({
      url: `/common/pages/addrList/index`,
    })
  },
  goCityList: function () {
    API_ADPTER.navigateTo({
      url: `/common/pages/cityList/index`,
    })
  },
})
