import {
  getChooseContent as apiGetChooseContent,
  commitReasonRequest,
} from './api'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  orderId: '',
  name: '取消原因选择',
  data: {
    chooseContentMap: [
      {
        title: '达达骑士的原因',
        responsibleParty: 1,
      },
      {
        title: '我的原因',
        responsibleParty: 2,
      },
      {
        title: '其他的原因',
        responsibleParty: 3,
      },
      {
        title: '特殊原因',
        responsibleParty: 4,
      },
      {
        title: '平台的原因',
        responsibleParty: 5,
      },
    ],
    chooseContent: [],
    chosenId: '',
    reasonContent: '',
    otherReason: '',
    contentMaxLength: 200,
    btnLoading: false,
  },

  onShow() {
    const { activeOrderId: orderId } = app.globalData.orderDetailInfo

    this.orderId = orderId

    const CHOOSE_CONTENT = API_ADPTER.getStorageSync('CHOOSE_CONTENT')

    if (CHOOSE_CONTENT) {
      this.setData({
        chooseContent: CHOOSE_CONTENT,
        hasCommit: false,
      })
    } else {
      this.setData({
        showLoading: true,
        hasCommit: false,
      })
    }

    this.getChooseContent()
  },
  getChooseContent() {
    apiGetChooseContent({
      orderId: app.globalData.orderDetailInfo.activeOrderId,
    }).then(chooseContent => {
      let array = this.mapInit()

      chooseContent.map(each => {
        let index = each.responsibleParty - 1
        if (index > -1 && index < 5) {
          if (array[index].content === undefined) {
            array[index].content = [each]
          } else {
            array[index].content.push(each)
          }
        }
      })

      this.setData({
        chooseContent: array,
        showLoading: false,
      })

      API_ADPTER.setStorageSync('CHOOSE_CONTENT', array)
    })
  },

  mapInit() {
    let list = []
    this.data.chooseContentMap.map(each => {
      let temp = {}
      temp.title = each.title
      temp.responsibleParty = each.responsibleParty
      temp.content = []

      list.push(temp)
    })

    return list
  },

  toggleChecked(e) {
    let { id, info } = e.currentTarget.dataset
    let notChoose = this.data.chosenId === id

    this.setData({
      chosenId: notChoose ? '' : id,
      reasonContent: notChoose ? '' : info,
      otherReason: '',
    })
  },

  bindTextAreaInput(e) {
    this.setData({
      otherReason: e.detail.value,
      chosenId: 10000,
      reasonContent: '',
    })
  },

  commitReason() {
    if (this.data.hasCommit) return

    if (!this.data.chosenId) {
      API_ADPTER.showToast({
        icon: 'none',
        title: '请选择取消原因',
      })
      return
    }

    if (this.data.chosenId === 10000 && this.data.otherReason.length <= 5) {
      API_ADPTER.showToast({
        icon: 'none',
        title: '内容过短最少输入5个字',
      })
      return
    }

    let params = {
      reasonId: this.data.chosenId,
      orderId: app.globalData.orderDetailInfo.activeOrderId,
      reasonContent: this.data.otherReason || this.data.reasonContent,
      orderStatus: (API_ADPTER.getStorageSync('ORDER_DETAIL_INFO') || {}).status,
    }

    for (let attr in params) {
      if (!params[attr]) delete params[attr]
    }

    this.setData({
      btnLoading: true,
    })

    commitReasonRequest(params)
      .then(res => {
        this.setData({
          btnLoading: false,
          hasCommit: true,
        })

        API_ADPTER.showToast({
          title: res,
          icon: 'success',
        })

        setTimeout(() => {
          API_ADPTER.navigateBack({
            delta: 2,
          })
        }, 1000)
      })
      .catch(() => {
        this.setData({
          btnLoading: false,
        })
      })
  },
})
