import { fetchCityList, checkCityBwm } from './api'
import track from 'track-mini-program'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  name: '城市列表',
  data: {
    list: [],
    currentLocation: {},
    isOpen: true,
  },
  onShow() {
    this.setData({
      currentLocation: app.globalData.commonAddress.currentLocation,
    })

    this.getCityList().then(() => {
      const city = app.globalData.commonAddress.currentLocation.city
      const isOpen =
        this.data.list.findIndex(item => item.cityName === city) >= 0

      this.setData({ isOpen })

      track.manuallyTrack({
        clickId: 'ClickReportPage',
        clickPar: {
          location_is_ok: city ? 1 : 0,
          service_is_open: isOpen ? 1 : 0,
          city_name: city,
        },
      })
    })
  },
  // 获取城市列表
  getCityList: function () {
    let COMMON_CITY_LIST = API_ADPTER.getStorageSync('COMMON_CITY_LIST')

    if (COMMON_CITY_LIST) {
      COMMON_CITY_LIST = COMMON_CITY_LIST.map(item => ({
        ...item,
        city: item.cityName.substring(0, item.cityName.length - 1),
      }))
      this.setData({ list: COMMON_CITY_LIST })
    }

    return fetchCityList().then(list => {
      list = list.map(item => ({
        ...item,
        city: item.cityName.substring(0, item.cityName.length - 1),
      }))
      this.setData({ list })
    })
  },
  handleCityClick: function (e) {
    const { adCode } = e.currentTarget.dataset
    const { isBwm } = app.globalData

    if (!adCode) return

    if (isBwm) {
      checkCityBwm({
        adCode,
      }).then(res => {
        if (res.status !== 'success') return
        this.changeCommonAddress(e)
      })
    } else {
      this.changeCommonAddress(e)
    }

    track.manuallyTrack({
      clickId: 'ClickChangeCity',
      clickPar: { city_name: e.currentTarget.dataset.cityName },
    })
  },
  changeCommonAddress: function (e) {
    const { cityName } = e.currentTarget.dataset
    let location = { ...this.data.currentLocation }

    if (cityName !== location.city) {
      const city = this.data.list.filter(item => item.cityName === cityName)[0]
      location = {
        city: city.cityName,
        adCode: city.adCode,
        cityCode: city.cityCode,
      }
    }

    app.globalData.commonAddress.location = location
    API_ADPTER.navigateBack()
  },
})
