import { login } from 'src/common/utils/login'
import { getOrderCoupon, getAnyCoupon } from './api'
import track from 'track-mini-program'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  name: '优惠券列表',
  data: {
    tabItem: ['未使用', '已使用', '已过期'],
    activeTabItem: 0,
    status: 1,
    pageNum: 1,
    totalPage: 1,
    currentPageNum: 1,
    couponList: [],
    from: '',
    showMenu: true,
    title: '',
  },
  onShow() {
    let from = app.globalData.commonCoupon.from
    let activeCouponId = app.globalData.commonCoupon.activeCouponId

    this.setData({
      from: from,
      showMenu: from !== 'orderCoupon',
      activeCouponId: activeCouponId || '',
    })

    const title = from === 'orderCoupon' ? '请选择可用优惠券' : '我的优惠券'

    API_ADPTER.setNavigationBarTitle({ title })
    this.setData({ title })

    login(app).then(res => {
      // 延时为应对IOS真机页面显示异常
      if (res.token) {
        setTimeout(API_ADPTER.startPullDownRefresh, 300)
      }
    })
  },
  tabItemChange(event) {
    let tabIndex = event.detail.index
    this.setData({
      activeTabItem: tabIndex,
    })
    this.changeTabRequest(tabIndex)
  },
  changeTabRequest(index) {
    const map = {
      0: 1,
      1: 1003,
      2: 1004,
    }

    this.setData({
      status: map[index],
      couponList: [],
      pageNum: 1,
    })

    API_ADPTER.startPullDownRefresh()
  },
  onPullDownRefresh: function () {
    this.setData({
      pageNum: 1,
    })
    this.getCouponListByPage()
  },
  onReachBottom: function () {
    if (this.data.currentPageNum === this.data.totalPage) return false
    this.getCouponListByPage()
  },
  getCouponListByPage() {
    if (this.data.from === 'myCoupon' || this.data.status !== 1) {
      this.getAnyCouponRequest().then(API_ADPTER.stopPullDownRefresh)
    } else if (this.data.from === 'orderCoupon') {
      this.getAvailableCoupon()
    }
  },
  getAvailableCoupon() {
    return getOrderCoupon({
      totalPrice: app.globalData.commonCoupon.totalPrice || '',
      distance: app.globalData.commonCoupon.distance,
      couponId: this.data.activeCouponId || '',
      sourceFrom: 'WECHAT-APP',
      PageSize: 10,
      orderScene: app.globalData.commonCoupon.orderScene,
    })
      .then(res => {
        API_ADPTER.stopPullDownRefresh()
        this.setCouponData({
          datas: res,
        })
      })
      .catch(() => {
        API_ADPTER.stopPullDownRefresh()
      })
  },

  getAnyCouponRequest() {
    return getAnyCoupon({
      status: this.data.status,
      pageNum: this.data.pageNum,
      sourceFrom: 'WECHAT-APP',
      pageSize: 10,
    })
      .then(res => {
        API_ADPTER.stopPullDownRefresh()
        this.setCouponData(res)
      })
      .catch(() => {
        API_ADPTER.stopPullDownRefresh()
      })
  },

  setCouponData(res) {
    let list = []
    if (this.data.pageNum === 1) {
      list = res.datas
    } else {
      list = [...this.data.couponList, ...res.datas]
    }

    this.setData({
      currentPageNum: res.pageNo || 1,
      couponList: list,
      totalPage: res.totalPage || 1,
    })

    if (this.data.pageNum < this.data.totalPage) {
      this.setData({
        pageNum: this.data.pageNum + 1,
      })
    }
  },

  chooseCouponListener(event) {
    let activeId = event.detail.couponId

    if (this.data.status === 1 && this.data.from === 'orderCoupon') {
      const status =
        +app.globalData.commonCoupon.activeCouponId === +activeId
          ? 'unselect'
          : 'select'

      track.manuallyTrack({
        clickId: 'ClickChooseCoupon',
        clickPar: {
          status,
          coupon_code: activeId,
        },
      })
      if (app.globalData.commonCoupon.activeCouponId === null) {
        app.globalData.commonCoupon.activeCouponId = activeId
      } else {
        app.globalData.commonCoupon.activeCouponId =
          +app.globalData.commonCoupon.activeCouponId === +activeId
            ? -1
            : activeId
      }
      API_ADPTER.navigateBack()
    }
  },
})
