import { getWalkingLine } from '../../utils/map'
import { ORDER_FEE_INFO } from '../../constants/feeInfo'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  name: '费用明细',
  data: {
    ...ORDER_FEE_INFO,
    map: {
      markers: [{}, {}],
      style: 'width: 100%; height: 400rpx; border-radius: 4rpx;',
      polyline: [
        {
          points: [],
          color: '#1287FFDD',
          width: 4,
        },
      ],
      scale: 16,
    },
  },
  onLoad: function () {
    let { feeInfo } = app.globalData.commonOrderFeeInfo
    feeInfo.basePrice = Number(feeInfo.basePrice || 0).toFixed(1)
    feeInfo.couponAmount = Number(feeInfo.couponAmount || 0).toFixed(1)
    feeInfo.deliverFee = Number(feeInfo.deliverFee || 0).toFixed(1)
    feeInfo.distanceDesc =
      feeInfo.distance >= 1000
        ? `${Number(feeInfo.distance / 1000).toFixed(1)}公里`
        : `${Number(feeInfo.distance).toFixed(1)}米`
    feeInfo.distancePrice = Number(feeInfo.distancePrice || 0).toFixed(1)
    feeInfo.dynamicPrice = Number(feeInfo.dynamicPrice || 0).toFixed(1)
    feeInfo.freightCouponAmount = Number(
      feeInfo.freightCouponAmount || 0
    ).toFixed(1)
    feeInfo.heavyWeatherPrice = Number(feeInfo.heavyWeatherPrice || 0).toFixed(
      2
    )
    feeInfo.needPay = Number(feeInfo.needPay || 0).toFixed(1)
    feeInfo.orderValue = Number(feeInfo.orderValue || 0).toFixed(1)
    feeInfo.orderWeight = Number(feeInfo.orderWeight || 0).toFixed(1)
    feeInfo.peakTimePrice = Number(feeInfo.peakTimePrice || 0).toFixed(1)
    feeInfo.riverPrice = Number(feeInfo.riverPrice || 0).toFixed(1)
    feeInfo.tipCouponAmount = Number(feeInfo.tipCouponAmount || 0).toFixed(1)
    feeInfo.tips = Number(feeInfo.tips || 0).toFixed(1)
    feeInfo.totalPrice = Number(feeInfo.totalPrice || 0).toFixed(1)
    feeInfo.weightPrice = Number(feeInfo.weightPrice || 0).toFixed(1)
    feeInfo.insurance = Number(feeInfo.insurance || 0).toFixed(1)
    this.setData({ ...app.globalData.commonOrderFeeInfo, feeInfo })

    this.mapCtx = API_ADPTER.createMapContext('feeInfoMap')
    const BUY_MARKER = {
      id: 2,
      title: '店铺位置',
      iconPath: '/common/images/map-buy.png',
      height: 48,
      width: 36,
    }
    const RECEIVER_MARKER = {
      id: 3,
      title: '收货人位置',
      iconPath: '/common/images/map-receive.png',
      height: 48,
      width: 36,
    }
    const SENDER_MARKER = {
      id: 4,
      title: '发货人位置',
      iconPath: '/common/images/map-sender.png',
      height: 48,
      width: 36,
    }
    const TAKE_MARKER = {
      id: 4,
      title: '取货位置',
      iconPath: '/common/images/map-take.png',
      height: 48,
      width: 36,
    }
    const CALLOUT = {
      content: '',
      color: '#FFFFFF',
      fontSize: 14,
      borderRadius: 16,
      bgColor: '#535353',
      padding: 8,
      display: 'ALWAYS',
      textAlign: 'center',
    }
    const { routeInfo } = this.data
    if (!routeInfo.startLat || !routeInfo.endLat) return
    const start = {
      latitude: routeInfo.startLat,
      longitude: routeInfo.startLng,
    }
    const end = {
      latitude: routeInfo.endLat,
      longitude: routeInfo.endLng,
    }
    let marker
    switch (routeInfo.type) {
      case 'bws':
        marker = SENDER_MARKER
        break
      case 'bwm':
        marker = BUY_MARKER
        break
      case 'bwq':
        marker = TAKE_MARKER
        break
      default:
        marker = SENDER_MARKER
        break
    }
    let startMarker = {
      ...marker,
      latitude: start.latitude,
      longitude: start.longitude,
    }

    this.setData({
      'map.markers[0]': startMarker,
      'map.markers[1]': {
        ...RECEIVER_MARKER,
        latitude: end.latitude,
        longitude: end.longitude,
      },
      'map.markers[1].callout.': {
        ...CALLOUT,
        content: this.data.feeInfo.distanceDesc,
      },
    })
    this.mapCtx.includePoints({
      points: [start, end],
      padding: [80, 80, 80, 80],
    })

    getWalkingLine({
      fromLat: start.latitude,
      fromLng: start.longitude,
      toLat: end.latitude,
      toLng: end.longitude,
    }).then(res => {
      const path = [
        { longitude: start.longitude, latitude: start.latitude },
        ...res.path,
        { longitude: end.longitude, latitude: end.latitude },
      ]

      this.setData({
        'map.polyline[0].points': path,
      })
    })
  },
})
