import { login } from 'src/common/utils/login'
import { sendCode, register, getHash, getUserVerifyCode } from './api'
import { API_ADPTER } from 'src/common/adapters/index'
import goHome from 'src/common/utils/goHome'
import { setUserInfoSync } from 'src/common/utils/commonApi'

const app = getApp()

Page({
  name: '注册',
  data: {
    step: 1,
    stepTitle: '输入手机号码',
    tipTitle: '如该手机号未注册，将直接为您创建达达账号',
    phoneFoucs: false,
    codeError: false,
    showTimer: false,
    phoneValidate: false,
    codeValidate: false,
    phone: '',
    currentCursor: 0,
    validateCode: '',
    userInfo: {},
    formId: '',
    needPhotoValidateCode: false,
  },

  onShow: function () {
    this.setData({
      phoneFoucs: true,
    })
    this.getHash()
  },

  getHash() {
    getHash().then(res => {
      this.setData({
        hash: res.content.hash,
      })
      if (res.content.requestLimit) {
        this.setData({ needPhotoValidateCode: true })
      }
    })
  },

  nextClick() {
    if (this.data.step === 1 && this.data.needPhotoValidateCode) {
      this.getUserVerifyCode()
      return
    }

    this.sendValidateCode()
  },

  getUserVerifyCode() {
    getUserVerifyCode({
      hash: this.data.hash,
    }).then(res => {
      this.setData({
        photoValidateCodeSrc: res.content.dataUri,
        step: 2,
        stepTitle: '输入图片验证码',
      })
    })
  },

  setPhone(e) {
    let cursor = e.detail.cursor
    let reg = /^1[3|4|5|6|7|8][0-9]\d{8}$/
    let tempPhone = e.detail.value
    let trimPhone = tempPhone.replace(/[ ]/g, '').toString()
    let lastPhone = this.data.phone

    if (cursor > this.data.currentCursor) {
      if (trimPhone.length === 3 || trimPhone.length === 7) {
        tempPhone += ' '
        cursor += 1
      } else if (
        (tempPhone.length === 4 && lastPhone.length === 3) ||
        (tempPhone.length === 9 && lastPhone.length === 7)
      ) {
        tempPhone = tempPhone.slice(0, -1) + ' ' + tempPhone.slice(-1)
        cursor += 1
      }
    } else {
      if (trimPhone.length === 3 || trimPhone.length === 7) {
        tempPhone = tempPhone.toString().trim()
        cursor -= 1
      }
    }

    this.setData({
      phoneValidate: reg.test(trimPhone),
      phone: trimPhone,
      currentCursor: cursor,
    })

    return {
      value: tempPhone,
    }
  },

  setValidateCode(e) {
    if (e.detail.value.length < 4) {
      this.setData({
        codeValidate: false,
      })
    } else {
      this.setData({
        validateCode: e.detail.value,
        codeValidate: true,
      })
    }
  },

  // diff
  getPhotoVerifyCode() {
    getUserVerifyCode({ hash: this.data.hash }).then(res => {
      this.setData({ photoValidateCodeSrc: res.content.dataUri })
    })
  },
  // diff
  setPhotoValidateCode(e) {
    this.setData({
      photoValidateCode: e.detail.value,
    })
  },

  // diff
  sendValidateCode() {
    clearInterval(this.data.timer)

    // 刷新localsession
    const params = {
      phone: this.data.phone,
      type: 6, // todo
      hash: this.data.hash, // todo
      verifyCode: this.data.photoValidateCode,
    }

    sendCode(params)
      .then(res => {
        if (res.status === 'success') {
          API_ADPTER.showToast({
            title: '验证码已发送',
            icon: 'success',
          })

          this.setData({
            step: 3,
            stepTitle: `验证码发送至 ${this.data.phone}`,
          })

          this.changeTimerShow()
        }
      })
      .catch(() => {
        this.getPhotoVerifyCode()
      })
  },

  goBack() {
    this.setData({
      step: 1,
      stepTitle: '输入手机号码',
      showTimer: false,
      phone: '',
      phoneValidate: false,
    })
  },

  changeTimerShow() {
    this.setData({
      showTimer: !this.data.showTimer,
    })
  },

  confirmBind() {
    let { phone, validateCode } = this.data

    this.setData({
      canClick: false,
    })

    let params = {
      phone,
      validateCode,
    }

    register(params)
      .then(res => {
        this.setData({
          canClick: true,
        })

        if (res.status === 'success') {
          setUserInfoSync(res.content)

          API_ADPTER.navigateBack()
        } else {
          this.setData({
            stepTitle: `${res.errMsg}，请重新输入`,
            codeError: true,
          })
        }
      })
      .catch(err => {
        if (err.errMsg === '第三方账号已注册过，请直接登陆！') {
          login(app)
            .then(goHome)
            .catch(goHome)
        }
      })
  },

  handleSubmit(e) {},
})
