import dayjs from 'dayjs'
import { saveFormAndPrePay } from 'src/common/pages/login/api'
import { login } from '../../utils/login'
import { getBwmShareParams } from '../../utils/share'
import { ORDER_TYPE } from '../../constants/index'
import {
  fetchSplitGiftInfo,
  fetchAcceptTime,
  fetchOrderDetail,
  fetchSharePublicOrderDetail,
  genPayBill,
  genCashierPayBill,
  fetchShareOrderDetail,
  fetchCutPriceStatus,
  addCutPriceOrder,
} from './api'
import { getWalkingLine } from '../../utils/map'
import { navigateTo } from 'src/common/utils/navigate'
import track from 'track-mini-program'
import { SCENARIO_ID } from 'src/common/constants/scenarioId'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()
const MAP_INIT = {
  markers: [{}, {}],
  style: 'width: 100%; height: 60vh;',
  polyline: [
    {
      points: [],
      color: '#1287FFDD',
      width: 4,
    },
  ],
  scale: 16,
}
const TRANSPORTER_MARKER = {
  id: 1,
  title: '达达位置',
  iconPath: '/common/images/map-transporter.png',
  width: 40,
  height: 45,
}
const BUY_MARKER = {
  id: 2,
  title: '店铺位置',
  iconPath: '/common/images/map-buy.png',
  height: 48,
  width: 36,
}
const SENDER_MARKER = {
  id: 2,
  title: '发货位置',
  iconPath: '/common/images/map-sender.png',
  height: 48,
  width: 36,
}
const TAKE_MARKER = {
  id: 4,
  title: '取货位置',
  iconPath: '/common/images/map-take.png',
  height: 48,
  width: 36,
}
const RECEIVER_MARKER = {
  id: 3,
  title: '收货人位置',
  iconPath: '/common/images/map-receive.png',
  height: 48,
  width: 36,
}
const CALLOUT = {
  content: '',
  color: '#FFFFFF',
  fontSize: 14,
  borderRadius: 16,
  bgColor: '#535353',
  padding: 8,
  display: 'ALWAYS',
  textAlign: 'center',
}

Page({
  noTrack: true,
  orderId: '',
  name: '订单详情',
  dotTimer: '',
  num: 1,
  pollingTimer: '',
  data: {
    showGuide: false,
    hideShareTip: false,
    hasLogin: true,
    hasJurisdiction: true,
    openOrderId: '',
    heightCalculated: false,
    isBwm: true,
    showTimer: false,
    payRemainTime: '',
    orderDetail: {
      feeDetail: {},
      transporter: {},
    },
    prevOrderDetail: {
      feeDetail: {},
      transporter: {},
    },
    phone: '',
    statusIcon: '',
    btns: {},
    map: { ...MAP_INIT },
    dotContent: '',
    nearDadaCnt: '',
    acceptOrderTime: '',
    splitGiftInfo: {
      activityUi: {},
      instanceUi: {},
      mode: 0,
    },
    scene: '',
    showCutPriceModal: false,
    cutPriceInfo: {
      mode: 0,
      instanceCode: '',
    },
  },

  onShareAppMessage(options) {
    const { from, target } = options
    const { openOrderId, orderType } = this.data.orderDetail
    const defaultParams = getBwmShareParams()
    const path = `/common/pages/orderDetail/index?openOrderId=${encodeURIComponent(
      openOrderId
    )}`
    let title = '我正在使用「达达」给你寄送物品'

    // 分裂红包分享
    if (from === 'button' && target.dataset.shareType === 'splitGift') {
      const { splitGiftInfo } = this.data
      const { instanceUi } = splitGiftInfo
      const { wx_session: wxSession } = instanceUi

      return {
        title: wxSession.title,
        imageUrl: wxSession.thumbUrl,
        path: wxSession.path,
      }
    }

    if (orderType === ORDER_TYPE.BWM) {
      title = '我正在使用「达达」帮我跑腿代买'
    } else if (orderType === ORDER_TYPE.BWQ) {
      title = '我正在使用「达达」帮我取物品'
    } else if (orderType === ORDER_TYPE.BWS) {
      title = '我正在使用「达达」给你寄送物品'
    }

    const params = {
      title,
      imageUrl: 'https://fe.imdada.cn/bwm/0.0.2/image/share-detail.png',
      path,
    }

    return openOrderId ? params : defaultParams
  },

  onShow() {
    const pages = getCurrentPages()
    const { scene } = this.data
    let { openOrderId = '', orderId = '' } = pages[pages.length - 1].options

    this.setData({
      showGuide: !!(openOrderId || orderId || scene),
    })
    openOrderId = decodeURIComponent(openOrderId || scene)
    if (orderId) app.globalData.orderDetailInfo.activeOrderId = orderId
    this.setData({
      openOrderId,
      isBwm: app.globalData.orderDetailInfo.isBwm,
    })

    const { activeOrderId } = app.globalData.orderDetailInfo

    this.orderId = orderId || activeOrderId

    login(app, false)
      .then(res => {
        this.noTrack = false
        track.manuallyTrack()
        this.setData({
          hasLogin: true,
        })
        this.initPollingOrderDetail()
        this.initDotAnimation()
        this.reload()
      })
      .catch(res => {
        this.noTrack = false
        track.manuallyTrack()
        this.setData({
          hasLogin: false,
        })
        if (openOrderId) {
          this.initPollingOrderDetail()
          this.initDotAnimation()
          this.reload()

          return
        }
        API_ADPTER.navigateTo({ url: `/common/pages/login/index` })
      })

    if (this.orderId) {
      setTimeout(() => {
        fetchSplitGiftInfo({
          orderId: this.orderId,
          ver: 2,
        }).then(splitGiftInfo => this.setData({ splitGiftInfo }))
        !this.data.isBwm && this.getCutPriceStatus()
      }, 1000)
    }
  },

  onHide() {
    clearInterval(this.pollingTimer)
    clearInterval(this.dotTimer)
  },

  onUnload() {
    clearInterval(this.pollingTimer)
    clearInterval(this.dotTimer)
  },

  initPollingOrderDetail() {
    clearInterval(this.pollingTimer)
    this.pollingTimer = setInterval(() => {
      const { orderDetail } = this.data
      const { statusName } = orderDetail
      const stopFlag =
        statusName === '已取消' ||
        (statusName === '已完成' && statusName === '已送回发货人')

      if (stopFlag) {
        clearInterval(this.pollingTimer)

        return
      }
      this.reloadMayRenderMap()
    }, 5000)
  },

  reload() {
    this.requestDetail().then(() => {
      this.getAcceptTime()
      this.renderMap()
    })
  },

  getAcceptTime() {
    const { statusName, senderLat: lat, senderLng: lng } = this.data.orderDetail

    if (statusName !== '待接单' && statusName !== '待发布') return

    fetchAcceptTime({ lat, lng }).then(res => {
      this.setData({
        acceptOrderTime: (res.acceptSec / 60).toFixed(0),
        nearDadaCnt: res.transporterNum,
      })
    })
  },

  reloadMayRenderMap() {
    this.requestDetail().then(
      shouldRenderMap => shouldRenderMap && this.renderMap()
    )
  },

  initDotAnimation() {
    this.num = 1
    clearInterval(this.dotTimer)
    this.dotTimer = setInterval(() => {
      this.num = this.num + 1
      const dotNum = (this.num % 4) + 1
      const dotArr = []
      dotArr.length = dotNum
      const content = dotArr.join('.')
      this.setData({
        dotContent: content,
      })
    }, 500)
  },

  renderMap() {
    const { orderDetail, isBwm } = this.data
    const { statusName, orderType } = orderDetail
    let start
    let end
    let startMarkerInit
    let startMarker = SENDER_MARKER
    let endMarkerInit = RECEIVER_MARKER

    if (orderType === ORDER_TYPE.BWM) {
      startMarker = BUY_MARKER
    } else if (orderType === ORDER_TYPE.BWS) {
      startMarker = SENDER_MARKER
    } else if (orderType === ORDER_TYPE.BWQ) {
      startMarker = TAKE_MARKER
    }

    this.setMapHeight()
    if (statusName === '待支付') {
      start = {
        latitude: orderDetail.senderLat,
        longitude: orderDetail.senderLng,
      }
      startMarkerInit = startMarker
      end = {
        latitude: orderDetail.receiverLat,
        longitude: orderDetail.receiverLng,
      }
    } else if (statusName === '待接单' || statusName === '待发布') {
      start = {
        latitude: orderDetail.senderLat,
        longitude: orderDetail.senderLng,
      }
      startMarkerInit = startMarker
      const params = {
        'map.markers[0]': {
          ...startMarkerInit,
          latitude: start.latitude,
          longitude: start.longitude,
          callout:
            statusName === '待接单'
              ? {
                ...CALLOUT,
                content: '正在为您呼叫骑士',
              }
              : {},
        },
        'map.markers[1]': {},
        'map.polyline[0].points': [],
      }
      this.setData(params)
      this.mapCtx.includePoints({
        points: [start],
      })
      return
    } else if (statusName === '待取货') {
      start = {
        latitude: orderDetail.position.transporterLat,
        longitude: orderDetail.position.transporterLng,
      }
      startMarkerInit = TRANSPORTER_MARKER
      end = {
        latitude: orderDetail.position.senderLat,
        longitude: orderDetail.position.senderLng,
      }
      endMarkerInit = isBwm ? BUY_MARKER : SENDER_MARKER
    } else if (statusName === '派送中' || statusName === '配送中') {
      start = {
        latitude: orderDetail.position.transporterLat,
        longitude: orderDetail.position.transporterLng,
      }
      startMarkerInit = TRANSPORTER_MARKER
      end = {
        latitude: orderDetail.position.receiverLat,
        longitude: orderDetail.position.receiverLng,
      }
    } else if (
      statusName === '已完成' ||
      statusName === '已过期' ||
      statusName === '已取消'
    ) {
      start = {
        latitude: orderDetail.senderLat,
        longitude: orderDetail.senderLng,
      }
      startMarkerInit = startMarker
      end = {
        latitude: orderDetail.receiverLat,
        longitude: orderDetail.receiverLng,
      }
    }
    this.setData({
      'map.markers[0]': {
        ...startMarkerInit,
        latitude: start.latitude,
        longitude: start.longitude,
      },
      'map.markers[1]': {
        ...endMarkerInit,
        latitude: end.latitude,
        longitude: end.longitude,
      },
    })
    this.mapCtx.includePoints({
      points: [start, end],
      padding: [80, 80, 80, 80],
    })
    getWalkingLine({
      fromLat: start.latitude,
      fromLng: start.longitude,
      toLat: end.latitude,
      toLng: end.longitude,
    }).then(res => {
      const path = [
        { longitude: start.longitude, latitude: start.latitude },
        ...res.path,
        { longitude: end.longitude, latitude: end.latitude },
      ]

      this.setData({
        'map.polyline[0].points': path,
      })

      const { orderType } = this.data.orderDetail
      let content

      if (statusName === '待取货') {
        if (orderType === ORDER_TYPE.BWM) {
          content = `距店铺${this.getDistanceDesc(res.distance)}`
        } else if (orderType === ORDER_TYPE.BWS) {
          content = `距发货地${this.getDistanceDesc(res.distance)}`
        } else if (orderType === ORDER_TYPE.BWQ) {
          content = `距取货地${this.getDistanceDesc(res.distance)}`
        }

        this.setData({
          'map.markers[0].callout.': {
            ...CALLOUT,
            content,
          },
        })

        return
      }
      if (statusName === '派送中' || statusName === '配送中') {
        content = `距收货人${this.getDistanceDesc(res.distance)}`

        this.setData({
          'map.markers[0].callout.': {
            ...CALLOUT,
            content,
          },
        })
      }
    })
  },

  getDistanceDesc(dis) {
    if (dis < 1000) {
      return `${Number(dis || 0).toFixed(0)}米`
    }
    return `${Number(dis / 1000 || 0).toFixed(1)}公里`
  },

  onLoad(option) {
    const { scene = '' } = option

    this.setData({ scene })
    this.initShareTip()
    this.mapCtx = API_ADPTER.createMapContext('orderMap')
    app.globalData.orderDetailInfo.autoPay && this.genPayBillRequest()
  },

  requestDetail() {
    return this.getOrderDetail().then(res => {
      this.setData({
        prevOrderDetail: this.data.orderDetail,
      })
      this.setData({
        orderDetail: {
          ...res,
          expectFetchTime: res.expectFetchTime
            ? dayjs(res.expectFetchTime * 1000).format('YYYY年M月D日 HH:mm')
            : '',
          createTime: res.createTime
            ? dayjs(res.createTime * 1000).format('YYYY年M月D日 HH:mm')
            : '',
          distanceDesc: this.unitDistance(res.distance),
          feeDetail: res.feeDetail
            ? {
              ...res.feeDetail,
              needPayDesc: this.unit(res.feeDetail.needPay),
            }
            : {},
          transporter: res.transporter
            ? {
              ...res.transporter,
              scoreDesc: (res.transporter.score || 0).toFixed(1),
            }
            : {},
        },
        statusIcon: this.getIcon(res.status),
        btns: this.getBtns(res.status),
        phone: (res.transporter && res.transporter.phone) || '',
      })
      this.countdown()

      return this.shouldRenderMap()
    })
  },

  shouldRenderMap() {
    const { prevOrderDetail, orderDetail } = this.data
    let shouldRenderMap = false

    if (prevOrderDetail.status !== orderDetail.status) {
      shouldRenderMap = true
    }
    if (
      JSON.stringify(prevOrderDetail.position) !==
      JSON.stringify(orderDetail.position)
    ) {
      shouldRenderMap = true
    }

    return shouldRenderMap
  },

  getOrderDetail() {
    const { openOrderId, hasLogin } = this.data
    const { activeOrderId: orderId } = app.globalData.orderDetailInfo

    if (openOrderId && hasLogin) {
      return fetchShareOrderDetail({ openOrderId }, { toast: false }).catch(
        () => {
          this.setData({
            hasJurisdiction: false,
          })
          return this.fetchSharePublicOrderDetail(openOrderId)
        }
      )
    }
    if (openOrderId && !hasLogin) {
      return this.fetchSharePublicOrderDetail(openOrderId)
    }
    return fetchOrderDetail({ orderId })
  },

  fetchSharePublicOrderDetail(openOrderId) {
    return fetchSharePublicOrderDetail({ openOrderId }, { toast: false }).catch(
      res => {
        if (res.errCode === 6113) {
          API_ADPTER.showModal({
            title: '分享已过期',
            content: '该订单的分享已过期，点击按钮返回首页',
            showCancel: false,
            confirmText: '返回首页',
            confirmColor: '#1287ff',
            success: function (res) {
              const url = app.globalData.isBwm
                ? '/pages/home/index'
                : '/pages/index/index'

              API_ADPTER.reLaunch({
                url,
              })
            },
          })
        }
      }
    )
  },

  showModal() {
    API_ADPTER.showModal({
      title: '登录账号',
      content:
        '为了保护用户隐私，需要您使用收/发货人任意一方手机号登录，即可查看详细订单完整信息。',
      showCancel: true,
      cancelText: '取消',
      cancelColor: '#22252A',
      confirmText: '立即登录',
      confirmColor: '#1287ff',
      success: res => {
        if (res.confirm) this.goRegister()
      },
    })
  },

  goRegister() {
    API_ADPTER.navigateTo({
      url: `/common/pages/login/index`,
    })
  },

  countdown() {
    if (this.data.orderDetail.status !== 1011) return

    if (this.data.orderDetail.payRemainTime < 0) return

    this.setData({
      payRemainTime: this.data.orderDetail.payRemainTime,
      showTimer: true,
    })
  },

  getIcon(status) {
    const map = {
      1000: 'released-order',
      1001: 'released-order',
      1002: 'transporter',
      1003: 'transporter',
      1004: 'transporter',
      1005: 'pay-overtime',
      1007: 'pay-overtime',
      1008: 'released-order',
      1009: 'transporter',
      1010: 'transporter',
      1011: 'wait-pay',
      1040: 'pay-overtime',
      1041: 'pay-overtime',
    }

    return map[status] || 'released-order'
  },

  getBtns(status) {
    const map = {
      1000: {
        分享订单: true,
        取消订单: true,
      },
      1001: {
        分享订单: true,
        取消订单: true,
      },
      1002: {
        分享订单: true,
        取消订单: true,
        联系达达骑士: true,
      },
      1003: {
        分享订单: true,
        再下一单: true,
        联系达达骑士: true,
      },
      1004: {
        再下一单: true,
        联系达达骑士: true,
      },
      1005: {
        再下一单: true,
      },
      1007: {
        再下一单: true,
      },
      1008: {
        分享订单: true,
        取消订单: true,
      },
      // 1009: {
      //   联系达达骑士: true,
      // },
      // 1010: {
      //   联系达达骑士: true,
      // },
      1011: {
        取消订单: true,
        去支付: true,
      },
      // 1040: {
      //   去处理: true,
      // },
      // 1041: {
      //   再下一单: true,
      // },
    }

    return map[status] || {}
  },

  dateMS(time) {
    return `${Math.floor(time / 60)}分${
      time % 60 > 9 ? time % 60 : `0${time % 60}`
    }秒`
  },

  unitDistance(distance) {
    if (distance < 1000) return `${Number(distance || 0).toFixed(0)}m`

    return `${Number(distance / 1000 || 0).toFixed(1)}km`
  },

  unit(price) {
    price = Number(price).toFixed(1)

    return `${price}元`
  },

  changeTimerShow() {
    this.setData({
      showTimer: !this.data.showTimer,
    })
  },

  toOrderProgress() {
    const { openOrderId } = this.data
    const { activeOrderId: orderId } = app.globalData.orderDetailInfo
    const path = '/common/pages/orderProgress/index'
    const url = openOrderId
      ? `${path}?openOrderId=${encodeURIComponent(openOrderId)}`
      : `${path}?orderId=${orderId}`

    API_ADPTER.navigateTo({
      url,
    })
  },

  makePhoneCall: function () {
    // phone必须为字符串型
    API_ADPTER.makePhoneCall({
      phoneNumber: this.data.phone + '',
    })
  },

  goIndexHandle() {
    const { isBwm } = this.data

    if (isBwm) {
      return API_ADPTER.switchTab({
        url: '/pages/home/index',
      })
    }

    return API_ADPTER.reLaunch({
      url: '/pages/index/index?again=1',
    })
  },

  cancelOrderHandle() {
    API_ADPTER.navigateTo({
      url: '/common/pages/cancelConfirm/index',
    })
  },

  genPayBillRequest() {
    let params = null

    app.globalData.platform = 'swan'
    if (app.globalData.platform === 'weapp') {
      params = {
        preOrderId: app.globalData.orderDetailInfo.activeOrderId,
        clientType: 'WECHAT-APP',
        appletType: app.globalData.isBwm ? 'BWM' : 'DADA',
      }
      this.genPayBillRequestWX(params)
    } else {
      params = {
        orderId: app.globalData.orderDetailInfo.activeOrderId,
        clientType: 'MOBILE-WEB',
        appletType: app.globalData.isBwm ? 'BWM' : 'DADA',
      }
      this.genPayBillRequestSwan(params)
    }
  },

  genPayBillRequestWX(params) {
    genPayBill(params).then(res => {
      app.globalData.payBillInfo = res
      this.payHandle()
    })
  },

  genPayBillRequestSwan(params) {
    genCashierPayBill(params).then(res => {
      // app.globalData.payBillInfo = res
      // this.payHandle()
      const { flag, payUrl } = res

      if (!flag) {
        return
      }
      API_ADPTER.navigateTo({
        url: `/pages/activity/adPage/index?link=${encodeURIComponent(payUrl)}`,
      })
    })
  },

  payHandle() {
    let params = Object.assign({}, app.globalData.payBillInfo, {
      success: () => {
        saveFormAndPrePay({
          prepayId: app.globalData.payBillInfo.prePayId,
          scenarioId: SCENARIO_ID.order,
          appName: app.globalData.isBwm ? 'BWM' : 'DADA',
        })
        let i = 0
        let timer = setInterval(() => {
          if (this.data.orderDetail.status !== 1011 || i === 5) {
            clearInterval(timer)
            return
          }
          i = i + 1
          this.requestDetail()
        }, 1000)
        app.globalData.orderDetailInfo.autoPay = false
      },
      fail: () => {
        app.globalData.orderDetailInfo.autoPay = false
      },
    })

    API_ADPTER.requestPayment(params)
  },

  goFeeInfo: function () {
    const { orderDetail } = this.data
    const { orderType } = orderDetail
    let type

    app.globalData.commonOrderFeeInfo.feeInfo = {
      ...orderDetail.feeDetail,
      distance: orderDetail.distance,
    }
    if (orderType === ORDER_TYPE.BWM) {
      type = 'bwm'
    } else if (orderType === ORDER_TYPE.BWQ) {
      type = 'bwq'
    } else if (orderType === ORDER_TYPE.BWS) {
      type = 'bws'
    }
    app.globalData.commonOrderFeeInfo.routeInfo = {
      type,
      startLat: orderDetail.senderLat,
      startLng: orderDetail.senderLng,
      endLat: orderDetail.receiverLat,
      endLng: orderDetail.receiverLng,
    }
    API_ADPTER.navigateTo({
      url: '/common/pages/feeInfo/index',
    })
  },

  setMapHeight() {
    const { openOrderId } = this.data

    if (this.data.heightCalculated) return
    if (!API_ADPTER.createSelectorQuery) return
    API_ADPTER.createSelectorQuery()
      .select('#order-base-content')
      .boundingClientRect(function (rect) {})
      .exec(res => {
        const contentHeight = app.globalData.contentHeight
        let height = contentHeight - res[0].height - 10 - (openOrderId ? 58 : 0)

        this.setData({
          'map.style': `width: 100%; height: ${height}px;`,
          heightCalculated: true,
        })
      })
  },

  initShareTip() {
    const hideShareTip = API_ADPTER.getStorageSync('ORDER_DETAIL_HIDE_SHARE_TIP')

    this.setData({
      hideShareTip,
    })
  },

  handleHideShareTip() {
    API_ADPTER.setStorageSync('ORDER_DETAIL_HIDE_SHARE_TIP', true)

    this.setData({
      hideShareTip: true,
    })
  },

  toggleCutPriceModal() {
    this.setData({ showCutPriceModal: !this.data.showCutPriceModal })
  },

  getCutPriceStatus() {
    const orderId = this.orderId
    fetchCutPriceStatus({ orderId }).then(res => {
      if (res.mode === 1) {
        this.toggleCutPriceModal()
      }
      this.setData({ 'cutPriceInfo.mode': res.mode })
    })
  },

  handleGoCutPriceDetail() {
    const orderId = this.orderId

    addCutPriceOrder({ orderId }).then(res => {
      this.setData({ 'cutPriceInfo.instanceCode': res.instanceCode })
      const url = `/common/pages/activity/bargain/detail/index?instanceCode=${
        res.instanceCode
      }`
      app.globalData.activityBaseInfo.instanceCode = res.instanceCode
      if (this.data.showCutPriceModal) this.toggleCutPriceModal()
      navigateTo({ url })
    })
  },
})
