import { getOrderList } from './api'
import { checkLogin } from 'src/common/utils/login'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()
const navMap = [
  {
    key: '全部',
    value: 90,
  },
  {
    key: '待支付',
    value: 50,
  },
  {
    key: '待接单',
    value: 40,
  },
  {
    key: '进行中',
    value: 110,
  },
  {
    key: '已完成',
    value: 20,
  },
  {
    key: '已取消',
    value: 30,
  },
]
const initLocalPage = {
  count: true,
  endRow: 0,
  firstPage: false,
  hasNextPage: false,
  hasPreviousPage: false,
  isCount: 1,
  lastPage: false,
  nextPage: 0,
  pageNum: 1,
  pageSize: 10,
  pages: 0,
  prePage: 0,
  size: 0,
  startRow: 0,
  total: 0,
}

Page({
  name: '订单列表',
  data: {
    last: 0,
    hasLogin: false,
    navMap: [...navMap],
    activeKey: navMap[0].value,
    list: [],
    localPage: {
      ...initLocalPage,
    },
    isBwm: true,
  },
  onLoad() {
    this.setData({
      isBwm: app.globalData.isBwm,
    })
  },
  onShow: function () {
    const hasLogin = checkLogin({ mode: 'getLoginStatusOnly' })

    this.setData({
      hasLogin,
    })
    if (hasLogin) {
      setTimeout(API_ADPTER.startPullDownRefresh, 300)
    }
  },
  swiperChange(e) {
    const value = e.detail.currentItemId
    const index = navMap.findIndex(item => item.value === value)

    this.changeNav({ value, index })
  },
  handleChangeNav: function (e) {
    const { value, index } = e.currentTarget.dataset

    this.changeNav({ value, index })
  },
  changeNav({ value, index }) {
    if (!this.data.hasLogin) return

    this.setData({
      activeKey: value,
      activeIndex: index >= 2 ? index - 2 : 0,
    })
    API_ADPTER.startPullDownRefresh()
  },
  getOrderList: function () {
    const payload = {
      pageNum: this.data.localPage.pageNum,
      pageSize: this.data.localPage.pageSize,
      type: this.data.activeKey,
    }
    if (app.globalData.isBwm) {
      payload.orderType = 5
    }

    return getOrderList(payload).then(res => {
      let list = []
      if (this.data.localPage.pageNum === 1) {
        list = res.list
      } else {
        list = [...this.data.list, ...res.list]
      }
      this.setData({
        list: list,
        localPage: res.localPage,
      })
    })
  },
  goOrderDetail: function (e) {
    const order = e.currentTarget.dataset.order

    app.globalData.orderDetailInfo.activeOrderId = order.orderId
    app.globalData.orderDetailInfo.autoPay = false
    app.globalData.orderDetailInfo.isBwm = this.data.isBwm
    API_ADPTER.navigateTo({
      url: `/common/pages/orderDetail/index`,
    })
  },
  onPullDownRefresh() {
    const curr = +new Date()

    if (curr - this.data.last < 300) return
    this.setData({
      last: curr,
    })
    if (!this.data.hasLogin) {
      API_ADPTER.stopPullDownRefresh()
      return
    }
    this.setData({
      localPage: initLocalPage,
    })
    this.getOrderList().then(API_ADPTER.stopPullDownRefresh)
  },
  onReachBottom: function () {
    const curr = +new Date()

    if (curr - this.data.last < 300) return
    this.setData({
      last: curr,
    })
    if (this.data.localPage.hasNextPage) {
      this.setData({
        'localPage.pageNum': this.data.localPage.pageNum + 1,
      })
      this.getOrderList()
    }
  },
  goLogin: function () {
    API_ADPTER.navigateTo({
      url: `/common/pages/login/index`,
    })
  },
})
