import { fetchOrderProgress } from './api'
import dayjs from 'dayjs'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()
Page({
  orderId: '',
  name: '订单进度',
  pollingTimer: '',

  data: {
    openOrderId: '',
    orderProgress: {},
  },

  onShow: function () {
    const { activeOrderId: orderId } = app.globalData.orderDetailInfo
    const { openOrderId } = this.data

    this.orderId = orderId

    if (!openOrderId) {
      this.initPollingOrderProgress()
      this.getOrderProgress()
    }
  },

  onLoad(option) {
    let { openOrderId = '' } = option
    let ORDER_PROGRESS_INFO = API_ADPTER.getStorageSync('ORDER_PROGRESS_INFO')

    openOrderId = decodeURIComponent(openOrderId)
    if (ORDER_PROGRESS_INFO) {
      const progress = ORDER_PROGRESS_INFO.progress.map(each => ({
        ...each,
        time: dayjs(each.time * 1000).format('YYYY年MM月DD日 HH:mm'),
        icon: this.getStepIcon(each.statusName),
      }))

      this.setData({
        openOrderId,
        orderProgress: { progress },
      })
    } else {
      this.setData({
        openOrderId,
      })
    }
  },

  onHide() {
    clearInterval(this.pollingTimer)
  },

  onUnload() {
    clearInterval(this.pollingTimer)
  },

  initPollingOrderProgress() {
    clearInterval(this.pollingTimer)
    this.pollingTimer = setInterval(() => {
      const { orderProgress } = this.data
      const { progress } = orderProgress
      const statusName = progress[0].statusName
      const stopFlag =
        statusName === '已取消' ||
        (statusName === '已完成' && statusName === '已送回发货人')

      if (stopFlag) {
        clearInterval(this.pollingTimer)

        return
      }
      this.getOrderProgress()
    }, 5000)
  },

  getOrderProgress() {
    const { activeOrderId: orderId } = app.globalData.orderDetailInfo

    fetchOrderProgress({ orderId }).then(res => {
      res.progress.map((each, index) => {
        each.time = dayjs(each.time * 1000).format('YYYY年MM月DD日 HH:mm')
        if (index === 0) {
          each.icon = this.getStepIcon(each.statusName)
        } else {
          each.icon = this.getStepIcon()
        }
      })

      this.setData({
        orderProgress: res,
      })
    })
  },

  getStepIcon(statusName) {
    const map = {
      待支付: 'order-progress',
      待接单: 'order-progress',
      待发布: 'order-progress',
      待取货: 'order-progress',
      派送中: 'dispatching',
      配送中: 'dispatching',
      已完成: 'finish-status',
      已取消: 'finish-status',
      妥投失败待处理: 'dispatching',
      已送回发货人: 'finish-status',
    }

    return map[statusName] || 'order-progress'
  },
})
