import { requestChargeRules, genChargePayBill } from './api'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()
Page({
  name: '账户充值',
  data: {
    chargeRules: [],
    showLoading: false,
    activeChargeAmountId: 0,
    chargeAmount: 0,
    customChargeAmount: '',
    customChargeAmountInput: '',
    agreeRechargeProtocol: false,
    showAmountValueSlide: false,
    otherAmountText: '其他金额',
  },

  onShow() {
    API_ADPTER.setNavigationBarTitle({
      title: '账户充值',
    })

    this.queryChargeRules()
  },

  onLoad() {
    const ACCOUNT_CHARGE_RULES = API_ADPTER.getStorageSync('ACCOUNT_CHARGE_RULES')

    if (ACCOUNT_CHARGE_RULES) {
      this.setData({
        chargeRules: ACCOUNT_CHARGE_RULES,
      })
    } else {
      this.setData({
        showLoading: true,
      })
    }

    this.queryChargeRules()
  },

  queryChargeRules() {
    requestChargeRules().then(json => {
      let list = json.map(each => {
        return {
          ...each,
          chargeAmount: each.chargeAmount.toFixed(1),
        }
      })

      this.setData({
        showLoading: false,
        chargeRules: list,
        chargeAmount: list[0].chargeAmount,
      })
    })
  },

  changeChargeAmountHandle(event) {
    let id = event.currentTarget.dataset.id

    this.setData({
      activeChargeAmountId: id,
    })

    if (id >= 0) {
      this.setData({
        otherAmountText: '其他金额',
        chargeAmount: this.data.chargeRules[this.data.activeChargeAmountId]
          .chargeAmount,
      })
    }
    if (id === -1) {
      this.setData({
        showAmountValueSlide: !this.data.showAmountValueSlide,
      })
    }
  },

  changeAmountValue: function (e) {
    let amountValue = e.detail.value

    this.setData({
      customChargeAmountInput: amountValue,
    })
  },

  toggleAmountValueSlide: function () {
    this.setData({
      showAmountValueSlide: !this.data.showAmountValueSlide,
    })
  },

  confirmAmountChange() {
    let reg = /^[1-9]\d{0,4}$/

    if (!reg.test(this.data.customChargeAmountInput)) {
      API_ADPTER.showToast({
        title: '请输入正确的金额',
        icon: 'none',
      })
      return
    }

    this.toggleAmountValueSlide()
    this.setData({
      otherAmountText: this.data.customChargeAmountInput + '元',
      customChargeAmount: this.data.customChargeAmountInput,
    })
  },

  toggleRegisterProtocol() {
    this.setData({
      agreeRechargeProtocol: !this.data.agreeRechargeProtocol,
    })
  },

  showProtocol() {},

  payHandle() {
    if (!this.data.agreeRechargeProtocol) {
      API_ADPTER.showToast({
        title: '请先阅读并同意充值协议',
        icon: 'none',
      })

      return
    }

    if (this.data.activeChargeAmountId === -1 && this.data.chargeAmount < 50) {
      API_ADPTER.showToast({
        title: '充值金额不得少于50元',
        icon: 'none',
      })

      return
    }

    genChargePayBill({
      amount: this.data.chargeAmount,
      clientType: 'WECHAT-APP',
    }).then(res => {
      app.globalData.payBillParams = res
      this.requestPayMent()
    })
  },

  requestPayMent() {
    let params = Object.assign({}, app.globalData.payBillParams, {
      success: () => {
        API_ADPTER.showToast({
          title: '充值成功',
          icon: 'success',
          duration: 1000,
        })
        API_ADPTER.navigateTo({
          url: `/common/pages/home/index`,
        })
      },
      fail: function (res) {},
    })

    API_ADPTER.requestPayment(params)
  },
})
