import { login } from 'src/common/utils/login'
import { getUserInfoSync } from 'src/common/utils/commonApi'
import track from 'track-mini-program'

const app = getApp()
Page({
  noTrack: true,
  data: {
    showNavBar: false,
    webUrl: '',
    scoped: false,
    userInfo: {
      nickName: '',
      avatarUrl: '',
    },
  },
  onLoad() {
    if (app.globalData.systemInfo && app.globalData.systemInfo.version < '6.7.2') {
      this.setData({
        showNavBar: true,
      })
    }
  },
  onShow() {
    login(app, false).then(this.checkUserInfo).catch(this.checkUserInfo)
  },
  checkUserInfo() {
    wx.getSetting({
      success: (res) => {
        if (res.authSetting['scope.userInfo']) {
          // 已经授权，可以直接调用 getUserInfo 获取头像昵称
          this.scoped = true
          wx.getUserInfo({
            success: (res) => {
              this.setData({ userInfo: res.userInfo })
              this.loginCallback()
            },
          })
        } else {
          this.scoped = false
          this.loginCallback()
        }
      },
    })
  },
  loginCallback() {
    const pages = getCurrentPages()
    let { webUrl } = pages[pages.length - 1].options
    const { uid, token } = getUserInfoSync()
    const { nickName, avatarUrl } = this.data.userInfo

    this.noTrack = false
    track.manuallyTrack()

    webUrl = decodeURIComponent(webUrl)

    const flag = webUrl.slice(webUrl.indexOf('#')).indexOf('?') !== -1 ? '&' : '?'

    webUrl = `${webUrl}${flag}uid=${uid}&utoken=${token}&nickName=${encodeURIComponent(nickName)}&avatarUrl=${encodeURIComponent(avatarUrl)}`

    if (this.data.webUrl === webUrl) return

    this.setData({ webUrl: '' })
    setTimeout(() => {
      this.setData({ webUrl })
    }, 50)
  },
})
