import { pureGet } from 'src/common/utils/request'

const WEB_API_KEY = 'f8815efc1abacef798e4899185450425'

const reverseGeocoder = ({ lat, lng }) => {
  const params = {
    location: `${lng},${lat}`,
    extensions: 'all',
    key: WEB_API_KEY,
  }
  return pureGet('https://restapi.amap.com/v3/geocode/regeo', params).then(
    res => {
      if (res.status !== '1') throw new Error('amap reverseGeocoder fail')
      const {
        addressComponent: { adcode, city, province },
        pois,
      } = res.regeocode
      return {
        adCode: Number(adcode),
        city: city[0] || province,
        lat,
        lng,
        poi: {
          adCode: Number(adcode),
          city: city[0] || province,
          poiAddress: pois[0].address,
          poiName: pois[0].name,
          lng: pois[0].location.split(',')[0],
          lat: pois[0].location.split(',')[1],
        },
        poiList: pois.map(item => ({
          adCode: Number(item.adcode),
          city: city[0] || province,
          poiAddress: item.address,
          poiName: item.name,
          lng: pois[0].location.split(',')[0],
          lat: pois[0].location.split(',')[1],
          distance: Number(item.distance || 0).toFixed(1),
          distanceKM: (Number(item.distance || 0) / 1000).toFixed(2),
        })),
      }
    }
  )
}

const getWalkingLine = ({ fromLat, fromLng, toLat, toLng }) => {
  const from = `${fromLng},${fromLat}`
  const to = `${toLng},${toLat}`
  const params = {
    origin: from,
    destination: to,
    key: WEB_API_KEY,
  }
  return pureGet('https://restapi.amap.com/v3/direction/walking', params).then(
    res => {
      const { route, status } = res
      if (status !== '1') throw new Error('amap reverseGeocoder fail')
      const points = []
      let distance = 0

      if (route.paths && route.paths[0] && route.paths[0].steps) {
        const steps = route.paths[0].steps
        distance = route.paths[0].distance

        for (let i = 0; i < steps.length; i++) {
          const poLen = steps[i].polyline.split(';')
          for (let j = 0; j < poLen.length; j++) {
            points.push({
              longitude: parseFloat(poLen[j].split(',')[0]),
              latitude: parseFloat(poLen[j].split(',')[1]),
            })
          }
        }
      }

      console.log(points)
      return { path: points, distance }
    }
  )
}

// 获取高德poi信息
const getPoiByKeyword = ({
  city,
  location = {},
  keyword = '',
  preferredDistance = false,
}) => {
  let params = {}
  let url = ''
  if (preferredDistance) {
    params = {
      extensions: 'all',
      keywords: keyword,
      city,
      radius: 5000,
      offset: 30,
      sortrule: 'distance',
      key: WEB_API_KEY,
    }
    url = 'https://restapi.amap.com/v3/place/around'
  } else {
    params = {
      extensions: 'all',
      keywords: keyword,
      city,
      citylimit: true,
      offset: 30,
      sortrule: 'weigth',
      key: WEB_API_KEY,
    }
    url = 'https://restapi.amap.com/v3/place/text'
  }
  if (location.lat) {
    params.location = `${location.lng},${location.lat}`
  }

  return pureGet(url, params).then(res => {
    if (res.status !== '1') throw new Error('amap getPoiByKeyword fail')
    const list = res.pois.filter(item => item.location.length).map(item => ({
      adCode: Number(item.adcode),
      poiName: String(item.name),
      poiAddress: String(item.address) || String(item.name),
      lat: item.location.split(',')[1],
      lng: item.location.split(',')[0],
      cityName: String(item.cityname) || city,
      distance: Number(item.distance || 0),
      distanceKM: (Number(item.distance || 0) / 1000).toFixed(2),
    }))

    return list
  })
}

export const getLocationByIp = () => {
  const params = {
    key: WEB_API_KEY,
  }
  return pureGet('https://restapi.amap.com/v3/ip', params).then(res => {
    if (res.status !== '1') throw new Error('amap getLocationByIp fail')
    const { adcode, city, rectangle } = res
    const rectangleList = rectangle.split(';').map(item => item.split(','))

    return {
      adCode: Number(adcode),
      city,
      lng: (Number(rectangleList[0][0]) + Number(rectangleList[1][0])) / 2,
      lat: (Number(rectangleList[0][1]) + Number(rectangleList[1][1])) / 2,
    }
  })
}

const amap = {
  reverseGeocoder,
  getWalkingLine,
  getPoiByKeyword,
  getLocationByIp,
}

export default amap
