import { getSortParams } from './params'
import { API_ADPTER } from 'src/common/adapters/index'

const get3rdSession = (app, payload) => {
  return new Promise((resolve, reject) =>
    API_ADPTER.request({
      url: `${app.globalData.domain}applet/get3rdSession`,
      header: {
        'content-type': 'application/x-www-form-urlencoded',
      },
      method: 'POST',
      data: getSortParams(payload),
      success: res => {
        if (res.data.status === 'success') {
          return resolve(res.data)
        } else {
          return reject(res.data)
        }
      },
      fail: res => {
        return reject(res.data)
      },
    })
  ).catch(res => {
    return Promise.reject(res)
  })
}

const login = (app, payload) => {
  return new Promise((resolve, reject) => {
    return API_ADPTER.request({
      url: `${app.globalData.domain}applet/login`,
      header: {
        'content-type': 'application/x-www-form-urlencoded',
      },
      method: 'POST',
      data: getSortParams(payload),
      success: res => {
        resolve(res.data)
      },
      fail: res => {
        return reject(res)
      },
    })
  }).catch(res => {
    return Promise.reject(res)
  })
}

const setUserInfoSync = info => {
  API_ADPTER.setStorageSync('TOKEN', info.token || info.ticket)
  API_ADPTER.setStorageSync('UID', info.uid)
  API_ADPTER.setStorageSync('PHONE', info.phone)
}

const getUserInfoSync = () => ({
  token: API_ADPTER.getStorageSync('TOKEN'),
  uid: API_ADPTER.getStorageSync('UID'),
  phone: API_ADPTER.getStorageSync('PHONE'),
  openValue: API_ADPTER.getStorageSync('OPEN_VALUE'),
  openDigest: API_ADPTER.getStorageSync('OPEN_DIGEST'),
})

const removeUserInfoSync = () => {
  API_ADPTER.removeStorageSync('TOKEN')
  API_ADPTER.removeStorageSync('UID')
  API_ADPTER.removeStorageSync('PHONE')
}

const setUserWxInfoSync = info => {
  API_ADPTER.setStorageSync('NICK_NAME', info.nickName)
  API_ADPTER.setStorageSync('AVATAR_URL', info.avatarUrl)
  API_ADPTER.setStorageSync('GENDER', info.gender)
  API_ADPTER.setStorageSync('PROVINCE', info.province)
  API_ADPTER.setStorageSync('CITY', info.city)
}

const getUserWxInfoSync = () => ({
  nickName: API_ADPTER.getStorageSync('NICK_NAME'),
  avatarUrl: API_ADPTER.getStorageSync('AVATAR_URL'),
  gender: API_ADPTER.getStorageSync('GENDER'),
  province: API_ADPTER.getStorageSync('PROVINCE'),
  city: API_ADPTER.getStorageSync('CITY'),
})

const removeUserWxInfoSync = () => {
  API_ADPTER.removeStorageSync('NICK_NAME')
  API_ADPTER.removeStorageSync('AVATAR_URL')
  API_ADPTER.removeStorageSync('GENDER')
  API_ADPTER.removeStorageSync('PROVINCE')
  API_ADPTER.removeStorageSync('CITY')
}

export {
  get3rdSession,
  login,
  setUserInfoSync,
  getUserInfoSync,
  removeUserInfoSync,
  setUserWxInfoSync,
  getUserWxInfoSync,
  removeUserWxInfoSync,
}
