// 开发文档 http://lbs.qq.com/qqmap_wx_jssdk/index.html
import { pureGet } from './request'

// KEY 已添加 servicewechat.com 到域名白名单
const WEB_API_KEY = 'N6HBZ-6GSCU-R4YVE-BBFYK-KVP3T-F5BZJ'

// 规划步行路线，返回坐标点和距离
const getWalkingLine = ({ fromLat, fromLng, toLat, toLng }) => {
  const payload = {
    from: `${fromLat},${fromLng}`,
    to: `${toLat},${toLng}`,
    key: WEB_API_KEY,
  }
  return pureGet(
    'https://apis.map.qq.com/ws/direction/v1/walking/',
    payload
  ).then(res => {
    if (res.status !== 0) throw new Error('qqmap getWalkingLine fail')
    let coors = res.result.routes[0].polyline || []
    let path = []

    for (let i = 2; i < coors.length; i++) {
      coors[i] = coors[i - 2] + coors[i] / 1000000
    }
    for (let i = 0; i < coors.length; i += 2) {
      path.push({
        latitude: coors[i],
        longitude: coors[i + 1],
      })
    }

    return {
      path,
      distance: res.result.routes[0].distance || 0,
    }
  })
}

const getPoiByKeyword = ({ city, location = {}, keyword = '' }) => {
  let params = {
    keyword,
    output: 'json',
    orderby: '_distance',
    page_size: 20,
    key: WEB_API_KEY,
  }
  if (location.lat) {
    params = {
      ...params,
      boundary: `nearby(${location.lat},${location.lng},50000)`,
    }
  } else {
    params = {
      ...params,
      boundary: `region(${city || '全国'},0)`,
    }
  }

  return pureGet('https://apis.map.qq.com/ws/place/v1/search', {
    ...params,
  }).then(res => {
    if (res.status !== 0) throw new Error('qqmap getPoiByKeyword fail')
    const list = res.data.filter(item => item.location.lat).map(item => ({
      adCode: Number(item.ad_info.adcode),
      poiName: item.title,
      poiAddress: item.address,
      lat: item.location.lat,
      lng: item.location.lng,
      cityName: item.ad_info.city,
      distance: Number(item._distance || 0),
      distanceKM: (Number(item._distance || 0) / 1000).toFixed(2),
    }))

    return list
  })
}

const reverseGeocoder = ({ lat, lng }) => {
  const params = {
    location: `${lat},${lng}`,
    get_poi: 1,
    poi_options: 'page_size=10;policy=2',
    key: WEB_API_KEY,
  }
  return pureGet('https://apis.map.qq.com/ws/geocoder/v1/', {
    ...params,
  }).then(res => {
    if (res.status !== 0) throw new Error('qqmap reverseGeocoder fail')
    const {
      ad_info: { adcode, city },
      location: { lat, lng },
      pois,
    } = res.result
    return {
      adCode: Number(adcode),
      city,
      lat,
      lng,
      poi: {
        adCode: Number(pois[0].ad_info.adcode),
        city: pois[0].ad_info.city,
        poiAddress: pois[0].address,
        poiName: pois[0].title,
        lng: pois[0].location.lng,
        lat: pois[0].location.lat,
      },
      poiList: pois.map(item => ({
        adCode: Number(item.ad_info.adcode),
        city: item.ad_info.city,
        poiAddress: item.address,
        poiName: item.title,
        lng: item.location.lng,
        lat: item.location.lat,
        distance: Number(item._distance || 0),
        distanceKM: (Number(item._distance || 0) / 1000).toFixed(2),
      })),
    }
  })
}

const getLocationByIp = () => {
  const params = {
    key: WEB_API_KEY,
  }
  return pureGet('https://apis.map.qq.com/ws/location/v1/ip', {
    ...params,
  }).then(res => {
    if (res.status !== 0) throw new Error('qqmap getLocationByIp fail')
    return {
      adCode: Number(res.result.ad_info.adcode),
      city: res.result.ad_info.city,
      lat: res.result.location.lat,
      lng: res.result.location.lng,
    }
  })
}

const qqmap = {
  reverseGeocoder,
  getWalkingLine,
  getPoiByKeyword,
  getLocationByIp,
}

export default qqmap
