import { getSortParams } from './params'
import { removeUserInfoSync } from './commonApi'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()
let disableModal = false

const showModal = () => {
  if (disableModal) return

  disableModal = true
  removeUserInfoSync()
  API_ADPTER.showModal({
    title: '登录失效',
    content: '登录失效，点击确定重新登录',
    showCancel: false,
    confirmText: '重新登录',
    confirmColor: '#1287ff',
    success: function (res) {
      const url = app.globalData.isBwm
        ? '/pages/home/index'
        : '/pages/index/index'

      API_ADPTER.reLaunch({
        url,
        success: function () {
          disableModal = false
        },
      })
    },
  })
}

const showToast = msg => {
  if (msg.length >= 42) {
    API_ADPTER.showModal({
      title: '出错啦',
      content: msg,
      showCancel: false,
      confirmText: '我知道了',
      confirmColor: '#1287ff',
    })
  } else {
    API_ADPTER.showToast({
      title: msg,
      icon: 'none',
    })
  }
}

// 入参为json
const request = (method, url, params, options = {}) => {
  const { toast = true } = options

  return new Promise((resolve, reject) => {
    let header = {}
    const token = API_ADPTER.getStorageSync('TOKEN')
    const uid = API_ADPTER.getStorageSync('UID')

    if (token) {
      header['User-Token'] = token
    }
    if (uid) {
      header['User-Id'] = uid
    }

    API_ADPTER.request({
      url: `${app.globalData.domain}${url}`,
      header,
      method: method,
      data: params,
      success: res => {
        if (res.data.status === 'success') {
          return resolve(res.data)
        } else {
          // 登录失效后自动登录
          if (res.data.errCode === 6106 || res.data.errCode === 908) {
            showModal()
            return reject(res.data)
          }
          if (toast) {
            const msg = res.data.msg || res.data.errMsg || '接口请求出错'
            showToast(msg)
          }
          return reject(res.data)
        }
      },
      fail: res => {
        API_ADPTER.showToast({
          title: '无网络连接',
          icon: 'none',
        })
        return reject(res)
      },
    })
  })
}

const get = (url, params, options) => request('GET', url, params, options)
const post = (url, params, options) => request('POST', url, params, options)

// 入参为json
const pureRequest = (method, url, params, options = {}) => {
  return new Promise((resolve, reject) => {
    let header = {}

    API_ADPTER.request({
      url,
      header,
      method: method,
      data: params,
      success: res => {
        return resolve(res.data)
      },
      fail: res => {
        API_ADPTER.showToast({
          title: '无网络连接',
          icon: 'none',
        })
        return reject(res)
      },
    })
  })
}

const pureGet = (url, params, options) =>
  pureRequest('GET', url, params, options)
const purePost = (url, params, options) =>
  pureRequest('POST', url, params, options)

// 入参为form-data
const oldRequest = (method, url, params = {}, options = {}) => {
  const { toast = true } = options

  return new Promise((resolve, reject) => {
    let header = {}
    const token = API_ADPTER.getStorageSync('TOKEN')
    const uid = API_ADPTER.getStorageSync('UID')

    if (token) {
      header['User-Token'] = token
    }
    if (uid) {
      header['User-Id'] = uid
    }

    API_ADPTER.request({
      url: `${app.globalData.domain}${url}`,
      header: {
        'content-type': 'application/x-www-form-urlencoded',
        ...header,
      },
      method: method,
      data: getSortParams(params),
      success: res => {
        if (res.data.status === 'success') {
          return resolve(res.data)
        } else {
          // 登录失效后自动登录
          if (res.data.errCode === 6106 || res.data.errCode === 908) {
            showModal()
            return reject(res.data)
          }
          if (toast) {
            const msg = res.data.msg || res.data.errMsg || '接口请求出错'
            showToast(msg)
          }
          return reject(res.data)
        }
      },
      fail: res => {
        API_ADPTER.showToast({
          title: '无网络连接',
          icon: 'none',
        })
        return reject(res)
      },
    })
  })
}

const oldGet = (url, params, options) => oldRequest('GET', url, params, options)
const oldPost = (url, params, options) =>
  oldRequest('POST', url, params, options)

export { get, post, oldGet, oldPost, pureGet, purePost }
