import { register, saveFormAndPrePay } from '../../../common/pages/login/api'
import { setUserInfoSync } from '../../../common/utils/commonApi'
import { login } from '../../../common/utils/login'
import { fetchInvitePage, fetchPageCfg } from '../modal/businessApi'
import { getLocationPoi } from '../../../common/utils/location'
import track from 'track-mini-program'
import { SCENARIO_ID } from 'src/common/constants/scenarioId'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  noTrack: true,
  name: '邀请好友',
  data: {
    errorMsg: '',

    scene: '',
    pageCfgFinished: false,
    loginFinished: false,
    getCouponFinised: false,

    bannerSrc: '',
    bgColor: '',

    coupons: null,
    receiveTip: '',
    phone: '',
    reveiveBtnText: '',
    promoteCode: '',

    ruleTitle: '',
    ruleContent: [],

    ad: null,
    adTip: '',
  },

  onLoad(res) {
    this.setData({
      promoteCode: res.promoteCode || 'C67579',
    })
    // this.promoteCode = res.promoteCode || 'C67579'
    // this.channel = res.channel || 'activity_share'
    this.initData()
    this.initLogin()

    this.getPageConfig()
  },

  initData() {
    this.setData({
      adTip: '- 领取更多优惠券 -',
      receiveTip: '优惠券领取成功已放入以下账户',
      reveiveBtnText: '立即使用',
      ruleTitle: '活动细则',
      ruleContent: [
        '1、优惠券仅限新用户领取，同一用户仅可享受一次新用户优惠；',
        '2、发放至手机号的优惠券仅限该手机号使用；',
        '3、相同手机号、支付账号、微信号、设备号均视为同一个用户',
        '4、达达保留法律范围内的最终解释权。',
      ],
    })
  },

  initLogin() {
    // 登录
    login(app, true, true)
      .then(data => {
        this.noTrack = false
        track.manuallyTrack()
        this.setData({
          loginFinished: true,
          phone: app.globalData.activityBaseInfo.phone,
        })

        if (app.globalData.activityBaseInfo.loggedIn) {
          this.getPageOtherInfo()
        } else {
          this.setData({
            scene: 'login',
          })
        }
      })
      .catch(e => {
        this.noTrack = false
        track.manuallyTrack()
        this.setData({
          scene: 'error',
          loginFinished: true,
        })
      })
  },

  registerUser(event) {
    const that = this
    const { formId, ...registerParams } = event.detail
    register(registerParams).then(res => {
      if (res.status === 'success') {
        setUserInfoSync(res.content)
        app.globalData.activityBaseInfo.loggedIn = true
        that.setData({
          phone: res.content.phone,
        })
        // 注册成功 调用领券信息接口
        that.getPageOtherInfo()
        saveFormAndPrePay({
          formId,
          scenarioId: SCENARIO_ID.login,
          appName: 'DADA',
        })
      } else {
        API_ADPTER.showToast({
          title: res.errMsg + '，请重新输入',
          icon: 'none',
        })
      }
    })
  },

  setError(event) {
    this.setData({
      scene: 'error',
      errorMsg: event.detail ? event.detail : '',
    })
  },

  getPageOtherInfo() {
    getLocationPoi().then(res => {
      const that = this
      const params = {
        adCode: res.adCode,
        phone: this.data.phone,
        promoteCode: this.data.promoteCode,
      }

      fetchInvitePage(params)
        .then(res => {
          const participating = res.content.participating
          if (participating) {
            if (participating.mode === 0) {
              that.setData({
                scene: 'error',
                errorMsg: participating.message,
                getCouponFinised: true,
              })
            } else {
              if (participating.coupons) {
                that.setData({
                  scene: 'receive',
                  getCouponFinised: true,
                  coupons: participating.coupons,
                })
              }

              if (participating.mode === 2) {
                API_ADPTER.showToast({
                  title: '这是一个已领取的优惠券',
                  icon: 'none',
                })
              }
            }
          }

          const ad = res.content.ad
          if (ad && ad.length > 0) {
            that.setData({
              ad: ad[0],
            })
          }
        })
        .catch(() => {
          that.setData({
            scene: 'error',
            getCouponFinised: true,
          })
        })
    })
  },

  getPageConfig() {
    let params = {
      code: this.data.promoteCode,
    }

    fetchPageCfg(params).then(res => {
      this.setData({
        bannerSrc: res.content.targetTopImg,
        bgColor: res.content.targetBgColor,
        pageCfgFinished: true,
      })
    })
  },
})
