import { loadSignDetail, getLottery, getTaskId, getRewardChance } from './api'
import { TASK_STATUS_TYPE } from 'src/common/constants/taskStatusType'
import { API_ADPTER } from 'src/common/adapters/index'

Page({
  data: {
    rewardGrantStatusInfo: null,
    prizeList: null,
    rewardSummary: null,
    rewardRule: null,
    lotteryInfo: null,
    dialog: {
      showDialog: false,
      dialogStatus: 'signed',
    },
    bootAnimationShow: false,
    lotteryAnimationShow: false,
    currentLeft: '',
    screenWidth: 0,
    giftTop: '',
    disableBtn: false,
    showRule: false,
    showShare: false,
    showShareTip: false,
    taskId: '',
    taskStatus: [],
    showSuccess: false,
    lotteryBtntext: '',
  },
  onShow() {
    loadSignDetail().then(content => {
      let { dialog } = this.data
      const {
        checkInRewardSummary: rewardSummary,
        checkInRewardRule: rewardRule,
        taskStatus,
        rewardInfo: { rewardGrantStatus: rewardGrantStatusInfo, prizeList },
      } = content
      let leftNum = rewardGrantStatusInfo.leftNum
      let toTask = ''
      let unfinishedTask = null
      if (rewardSummary.isCheckInFirst) {
        dialog = {
          showDialog: true,
          dialogStatus: 'signSuccess',
        }
      }
      if (!leftNum && taskStatus.length) {
        unfinishedTask = taskStatus.find((value) => {
          return value.taskStatus === TASK_STATUS_TYPE.unreceived
        })
      }
      this.setData({
        dialog,
        toTask,
        rewardGrantStatusInfo,
        prizeList,
        rewardSummary,
        rewardRule,
        taskStatus,
        disableBtn: !leftNum,
        lotteryBtntext: leftNum > 1 ? `还有${leftNum}次抽奖机会` : '点击抽奖',
      })
      this.startBootAnimation()
      this.scrollToTask(unfinishedTask)
    })
  },
  startBootAnimation() {
    if (this.data.rewardGrantStatusInfo && !this.data.rewardGrantStatusInfo.leftNum) {
      this.setGiftUp(true)
      this.setData({
        bootAnimationShow: false,
      })
      return
    }
    this.setGiftUp(false)
    this.setData({
      bootAnimationShow: true,
    })
  },
  startLotteryAnimation(event) {
    if (this.data.rewardGrantStatusInfo && !this.data.rewardGrantStatusInfo.leftNum) {
      return
    }
    if (JSON.stringify(event.currentTarget) === JSON.stringify(event.target)) {
      this.getClientWidth()
      const params = {
        grantId: this.data.rewardGrantStatusInfo.grantId,
      }
      getLottery(params).then(content => {
        this.setData({
          lotteryInfo: content.prize,
        })
      })
      API_ADPTER.createSelectorQuery().select('.claw').boundingClientRect(res => {
        this.setData({
          currentLeft: `${(res.left + res.width / 2) / this.data.screenWidth * 100}%;`,
        })
      }).exec()
      this.setData({
        bootAnimationShow: false,
        lotteryAnimationShow: true,
      })
    }
  },
  endLotteryAnimation() {
    let dialog = {
      showDialog: true,
      dialogStatus: this.data.lotteryInfo.prizeType === 'nothing' ? 'nothing' : 'special',
    }
    let leftNum = this.data.rewardGrantStatusInfo.leftNum - 1
    this.setGiftUp(!leftNum)
    this.setData({
      dialog,
      lotteryBtntext: leftNum ? `还有${leftNum}次抽奖机会` : '已用完',
      bootAnimationShow: leftNum,
      lotteryAnimationShow: !leftNum,
      disableBtn: !leftNum,
      'rewardGrantStatusInfo.leftNum': leftNum,
    })
  },
  setGiftUp(isUp) {
    this.setData({
      giftTop: isUp ? '120rpx;' : '320rpx;',
    })
  },
  closeDialog() {
    this.setData({
      dialog: {
        ...this.data.dialog,
        showDialog: !this.data.dialog.showDialog,
      },
    })
  },
  getClientWidth() {
    API_ADPTER.getSystemInfo({
      success: res => {
        this.setData({
          screenWidth: res.screenWidth,
        })
      },
    })
  },
  onShareAppMessage(options) {
    return {
      title: '推荐你使用「达达」，同城帮取帮送1小时速达',
      path: `/pages/index/index?channel=share_home&taskId=${this.data.taskId}`,
      imageUrl: 'https://fe.imdada.cn/bwm/0.0.1/images/home-share.jpg',
      success: () => {
        this.setShareModal()
        this.setShareTip()
      },
    }
  },
  setTask(e) {
    this.closeDialog()
    this.scrollToTask(e.detail.unfinishedTask)
  },
  scrollToTask(params) {
    if (params) {
      API_ADPTER.pageScrollTo({
        scrollTop: 1500,
        duration: 300,
      })
    }
  },
  setRule() {
    this.setData({
      showRule: !this.data.showRule,
    })
  },
  setShareTip() {
    this.setData({
      showShareTip: !this.data.showShareTip,
    })
  },
  setShareModal(params = null) {
    if (!this.data.showShare && params) {
      this.getTaskId(params)
    }
    this.setData({
      showShare: !this.data.showShare,
    })
  },
  // 获取任务taskId，该taskId用来标示一次任务
  getTaskId(params) {
    getTaskId(params.detail).then((content) => {
      this.setData({
        taskId: content.taskId,
      })
    })
  },
  getReward(params) {
    getRewardChance(params.detail).then((content) => {
      let { leftNum } = content.rewardInfo.rewardGrantStatus
      if (leftNum) {
        this.setData({
          showSuccess: true,
          taskStatus: content.taskStatus,
          rewardGrantStatusInfo: content.rewardInfo.rewardGrantStatus,
          bootAnimationShow: true,
          lotteryAnimationShow: false,
          lotteryBtntext: `还有${leftNum}次抽奖机会`,
          disableBtn: !leftNum,
        })
        this.setGiftUp(!leftNum)
        setTimeout(() => {
          this.setData({
            showSuccess: false,
          })
        }, 1000)
      }
    })
  },
})
