import track from 'track-mini-program'
import { register, saveFormAndPrePay } from '../../../common/pages/login/api'
import {
  setUserInfoSync,
  getUserWxInfoSync,
} from '../../../common/utils/commonApi'
import { login, LOGIN_DIFF } from 'src/common/utils/login'
import { fetchSplitPacketPage } from '../modal/businessApi'
import { getLocationPoi } from '../../../common/utils/location'
import { SCENARIO_ID } from '../../../common/constants/scenarioId'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

Page({
  noTrack: true,
  name: '达达分享红包',
  data: {
    errorMsg: '',
    scene: '',
    pageCfgFinished: false,
    loginFinished: false,
    getCouponFinised: false,

    bannerSrc: 'https://fe.imdada.cn/mini-program/images/activity/splitPacket/top-v3.png',
    bgColor: '',

    coupons: [],
    receiveTip: '',
    phone: '',
    userId: '',
    reveiveBtnText: '',
    instanceCode: '',

    splits: [],

    ruleTitle: '',
    ruleContent: [],

    ad: null,
    adTip: '',
  },

  onLoad(res) {
    this.setData({
      instanceCode: res.instanceCode || 'split_gift20180517hHywir',
    })
    this.initData()
    this.initLogin()
  },

  initData() {
    this.setData({
      adTip: '- 福利升级还可再享以下优惠 -',
      receiveTip: '红包领取成功已放入以下账户',
      reveiveBtnText: '立即使用',
      ruleTitle: '活动细则',
      ruleContent: [
        '1、每位用户每天至多可以领取3张优惠券',
        '2、发放至手机号的优惠券仅限该手机号使用',
        '3、新人优惠券仅限新注册用户领取，每位用户仅限使用一次',
        '4、相同手机号/支付账号/微信号/设备号均视为同一用户',
        '5、达达保留法律范围内允许的对活动的解释权',
      ],
    })
  },

  initLogin() {
    const that = this
    // 登录
    login(app, true, true)
      .then(data => {
        this.noTrack = false
        track.manuallyTrack()
        if (data) {
          that.setData({
            phone: data.phone,
            userId: data.uid,
          })
        }

        if (app.globalData.activityBaseInfo.loggedIn) {
          that.getPageOtherInfo()
        } else {
          that.setData({
            scene: 'login',
          })
        }
        that.setData({
          loginFinished: true,
        })
      })
      .catch(e => {
        this.noTrack = false
        track.manuallyTrack()
        that.setData({
          scene: 'error',
          loginFinished: true,
        })
      })
  },

  registerUser(event) {
    const that = this
    const { formId, ...registerParams } = event.detail
    register(registerParams).then(res => {
      if (res.status === 'success') {
        setUserInfoSync(res.content)
        app.globalData.activityBaseInfo.loggedIn = true
        that.setData({
          phone: res.content.phone,
          userId: res.content.uid,
        })
        // 注册成功 调用领券信息接口
        that.getPageOtherInfo()
        saveFormAndPrePay({
          formId,
          scenarioId: SCENARIO_ID.login,
          appName: 'DADA',
        })
      } else {
        API_ADPTER.showToast({
          title: res.errMsg + '，请重新输入',
          icon: 'none',
        })
      }
    })
  },

  // 本地调试开发
  // onGotUserInfo: function(e) {
  //   // console.log(e.detail.userInfo)
  //   setUserWxInfoSync(e.detail.userInfo)

  //   this.getPageOtherInfo()
  // },

  setError(event) {
    this.setData({
      scene: 'error',
      errorMsg: event.detail ? event.detail : '',
    })
  },

  getPageOtherInfo2() {
    const userWxInfo = getUserWxInfoSync()

    getLocationPoi().then(res => {
      const that = this
      let params = {
        adCode: res.adCode,
        nickname: userWxInfo.nickName,
        avatar: userWxInfo.avatarUrl,
        userId: this.data.userId,
        instanceCode: that.data.instanceCode,
      }

      fetchSplitPacketPage(params)
        .then(res => {
          const participating = res.content.participating
          if (participating) {
            if (participating.mode === 0) {
              that.setData({
                scene: 'error',
                errorMsg: participating.message,
                getCouponFinised: true,
              })
            } else {
              if (participating.coupons) {
                that.setData({
                  scene: 'receive',
                  getCouponFinised: true,
                  coupons: participating.coupons,
                })
              }

              if (participating.mode === 2) {
                API_ADPTER.showToast({
                  title: '这是一个已抢过的红包',
                  icon: 'none',
                })
              }
            }
          }

          const participationRec = res.content.participationRec
          if (participationRec) {
            that.setData({
              splits: participationRec,
            })
          }

          const ad = res.content.ad
          if (ad && ad.length > 0) {
            that.setData({
              ad: ad[0],
            })
          }
        })
        .catch(() => {
          that.setData({
            scene: 'error',
            getCouponFinised: true,
          })
        })
    })
  },

  getPageOtherInfo() {
    const that = this
    Promise.all([getLocationPoi(), LOGIN_DIFF.getWxInfo()])
      .then(res => {
        const params = {
          adCode: res[0].adCode,
          nickname: res[1].nickName,
          avatar: res[1].avatarUrl,
          userId: that.data.userId,
          instanceCode: that.data.instanceCode,
        }

        fetchSplitPacketPage(params)
          .then(res => {
            const participating = res.content.participating
            if (participating) {
              if (participating.mode === 0) {
                that.setData({
                  scene: 'error',
                  errorMsg: participating.message,
                  getCouponFinised: true,
                })
              } else {
                if (participating.coupons) {
                  that.setData({
                    scene: 'receive',
                    getCouponFinised: true,
                    coupons: participating.coupons,
                  })
                }

                if (participating.mode === 2) {
                  API_ADPTER.showToast({
                    title: '这是一个已抢过的红包',
                    icon: 'none',
                  })
                }
              }
            }

            const participationRec = res.content.participationRec
            if (participationRec) {
              that.setData({
                splits: participationRec,
              })
            }

            const ad = res.content.ad
            if (ad && ad.length > 0) {
              that.setData({
                ad: ad[0],
              })
            }
          })
          .catch(() => {
            that.setData({
              scene: 'error',
              getCouponFinised: true,
            })
          })
      })
      .catch(res => {
        that.setData({
          scene: 'error',
          getCouponFinised: true,
        })
      })
  },
})
