import { post, get } from '../../common/utils/request'
import { getUuid, updateUuid } from 'src/common/utils/uuid'
import dayjs from 'dayjs'
import track from 'track-mini-program'
import * as payType from '../../common/constants/payType'
import { reverseGeocoder, getWalkingLine } from 'src/common/utils/map'
import { getAnyCoupon, getOrderCoupon } from 'src/common/pages/couponList/api'

const app = getApp()

export const getCouponsNum = () => {
  return getAnyCoupon({
    status: 1,
    pageNum: 1,
    sourceFrom: 'WECHAT-APP',
    pageSize: 1,
  }).then(res => res.totalCount || 0)
}

export const getAvailableCouponsNum = () => {
  return getOrderCoupon({
    totalPrice: app.globalData.commonCoupon.totalPrice || '',
    distance: app.globalData.commonCoupon.distance,
    couponId: '',
    sourceFrom: 'WECHAT-APP',
    PageSize: 1,
    orderScene: app.globalData.commonCoupon.orderScene,
  }).then(res => res.length || 0)
}

export const getOrderList = payload =>
  post('order/queryOrderList', payload).then(res => res.content)

export const getNearestSender = params => {
  return post(
    'client/getNearestSender',
    {
      ...params,
    },
    { toast: false }
  ).then(res => {
    return res.content
  })
}

export const queryAccountInfo = () =>
  get('v2/account/info/base', {}).then(res => res.content)

export const fetchAcceptTime = ({ lat, lng, adCode = '' }) => {
  const getAcceptTime = params =>
    get('order/map/shortest/fetch/time', {
      ...params,
      requestId: getUuid('CRINUM_REQUEST_UUID'),
    }).then(res => {
      return res.content
    })

  if (!adCode) {
    return reverseGeocoder({ lat, lng }).then(res =>
      getAcceptTime({ lat, lng, adCode: res.adCode })
    )
  }
  return getAcceptTime({ lat, lng, adCode })
}

export const fetchNearDada = params => {
  const _params = {
    ...params,
    distance: 0.5,
    requestId: getUuid('CRINUM_REQUEST_UUID'),
  }

  return get('order/map/neardadas/info', _params).then(res => {
    return res.content.knights || []
  })
}

const getFee = params => {
  const { commonAddress, commonCoupon } = app.globalData
  const { sender, receiver } = commonAddress
  const { orderBillInfo, currentOrderType, distance } = params
  const start = currentOrderType === 'send' ? sender : receiver
  const end = currentOrderType === 'send' ? receiver : sender
  const freightCouponId = commonCoupon.activeCouponId || ''
  // 处理不使用优惠券的缓存逻辑
  if (
    app.globalData.prev.senderPoiName !== sender.poiName ||
    app.globalData.prev.receiverPoiName !== receiver.poiName
  ) {
    app.globalData.prev.senderPoiName = ''
    app.globalData.prev.receiverPoiName = ''
    app.globalData.prev.freightCouponId = ''
  }

  if (freightCouponId === -1) {
    app.globalData.prev.senderPoiName = sender.poiName
    app.globalData.prev.receiverPoiName = receiver.poiName
    app.globalData.prev.freightCouponId = freightCouponId
  }
  const _params = {
    busiType: currentOrderType === 'send' ? 1 : 4,
    adCode: start.adCode,
    discountCouponId: '',
    distance,
    expectFetchTime: params.orderTime.selected.value,
    freightCouponId:
      app.globalData.prev.freightCouponId === -1 &&
      commonCoupon.activeCouponId === null
        ? -1
        : freightCouponId,
    isNeedFinishCode: Number(params.isNeedFinishCode),
    lat: start.lat,
    lng: start.lng,
    orderScene: params.currentOrderType === 'send' ? 1 : 2,
    orderValue: orderBillInfo.selectedCargo.selectedPrice,
    orderWeight: orderBillInfo.selectedCargo.cargoWeigh,
    receiverLat: end.lat,
    receiverLng: end.lng,
    receiverPhone: end.phone,
    requestId: getUuid('CRINUM_REQUEST_UUID'),
    senderPhone: start.phone,
    sourceFrom: 'WECHAT-APP',
    tipCouponId: '',
    tips: params.tips,
    insurance: orderBillInfo.insuranceFee || 0,
    insuredValue: orderBillInfo.insuredValue || 0,
  }

  return get('v2/order/fee/calculateCside', _params).then(data => {
    return data.content
  })
}

export const calcOrderFee = params => {
  const { sender, receiver } = app.globalData.commonAddress
  const { currentOrderType } = params
  const start = currentOrderType === 'send' ? sender : receiver
  const end = currentOrderType === 'send' ? receiver : sender

  return getWalkingLine({
    fromLat: start.lat,
    fromLng: start.lng,
    toLat: end.lat,
    toLng: end.lng,
  })
    .then(res =>
      getFee({
        ...params,
        distance: res.distance,
      })
    )
    .catch(() =>
      getFee({
        ...params,
        distance: 0,
      })
    )
}

export const addOrder = params => {
  const { commonAddress, commonOrderFeeInfo } = app.globalData
  const { sender, receiver } = commonAddress
  const { feeInfo } = commonOrderFeeInfo

  const start = params.currentOrderType === 'send' ? sender : receiver
  const end = params.currentOrderType === 'send' ? receiver : sender

  const _params = {
    requestId: getUuid('CRINUM_REQUEST_UUID'),
    typeTag: params.orderBillInfo.selectedCargo.selectedType,
    orderMsg: params.orderBillInfo.remarkValue,
    addOrderToken: feeInfo.addOrderToken,
    isNeedFinishCode: Number(params.isNeedFinishCode),
    busiType: params.currentOrderType === 'send' ? 1 : 4,
    payType: feeInfo.needPay > 0 ? params.payType : payType.PAY_TYPE_BALANCE,
    senderId: start.id,
    receiverId: end.id,
    receiverName: end.name,
    receiverPhone: end.phone,
    receiverPoiName: end.poiName,
    receiverPoiAddr: end.poiAddress,
    receiverDoor: end.doorplate,
    receiverLng: end.lng,
    receiverLat: end.lat,
    sourceFrom: 'WECHAT-APP',
  }

  return post('v2/order/cside/add', _params).then(res => {
    track.manuallyTrack({
      clickId: 'ClickToOrder',
      clickPar: { order_id: res.content.orderId },
    })
    track.manuallyTrack({
      clickId: 50019,
      clickPar: { order_id: res.content.orderId },
    })
    updateUuid('CRINUM_REQUEST_UUID')
    track.setExtParams({ request_id: getUuid('CRINUM_REQUEST_UUID') })
    return res.content
  })
}

export const fetchEstimateTime = (distance, type) => {
  const { commonAddress } = app.globalData
  const { sender, receiver } = commonAddress
  const _params = {
    distance: Number(distance).toFixed(0),
    adCode: sender.adCode,
    receiverLat: receiver.lat,
    receiverLng: receiver.lng,
    supplierLat: sender.lat,
    supplierLng: sender.lng,
  }

  return get('order/map/neardadas/estimate/time', _params).then(res => {
    const data = res.content

    return dayjs.unix(data.estimateFinishTime).format('HH:mm')
  })
}

export const getAdDisplay = payload =>
  get('growth/ad/supplier/display', payload).then(res => res.content)

export const fetchCouponMessage = () =>
  get('growth/coupon/message').then(res => res.content)
