import { fetchCargoTags } from './api'
import track from 'track-mini-program'
import { API_ADPTER } from 'src/common/adapters/index'

const app = getApp()

const state = {
  selectedCargo: {
    cargoTags: [],
    cargoPrices: [],
    selectedType: '',
    selectedTypeName: '未知',
    selectedTypeImg: '',
    selectedPrice: '',
    selectedPriceName: '未知',
    cargoWeigh: 1,
  },
  disableSubmit: true,
}

const actions = {
  initSelectCargo() {
    const selectedCargo = app.globalData.orderBillInfo.selectedCargo

    this.setData({
      selectedCargo: { ...this.data.selectedCargo, ...selectedCargo },
    })
    this.handleSubmitDisableToggle()
  },
  handleCargoConfirm(e) {
    const {
      selectedType,
      selectedPrice,
      selectedTypeName,
      selectedPriceName,
      cargoWeigh,
    } = this.data.selectedCargo
    track.manuallyTrack({
      clickId: 'ClickConfirmGoodsInfo',
      clickPar: {
        goods_type: selectedTypeName,
        goods_price: selectedPriceName,
        goods_weight: cargoWeigh,
      },
    })
    if (!selectedType) {
      API_ADPTER.showToast({
        title: '请选择物品品类',
        icon: 'none',
      })

      return
    }
    if (!selectedPrice) {
      API_ADPTER.showToast({
        title: '请选择物品价值',
        icon: 'none',
      })

      return
    }
    app.globalData.orderBillInfo.selectedCargo = {
      ...this.data.selectedCargo,
    }
    this.triggerEvent('ok', e)
  },
  handleCargoItemClick(e) {
    const { id, name } = e.currentTarget.dataset
    this.setData({
      selectedCargo: {
        ...this.data.selectedCargo,
        selectedType: id,
        selectedTypeName: name,
      },
    })
    this.handleSubmitDisableToggle()
  },
  handlePriceItemClick(e) {
    const { id, name } = e.currentTarget.dataset
    this.setData({
      'selectedCargo.selectedPrice': id,
      'selectedCargo.selectedPriceName': name,
    })
    this.handleSubmitDisableToggle()
  },
  handleWeighClick(e) {
    const { cargoWeigh } = this.data.selectedCargo
    const type = e.currentTarget.dataset.type

    if (type > 0 && cargoWeigh < 25) {
      return this.setData({
        'selectedCargo.cargoWeigh': cargoWeigh + 1,
      })
    }

    if (type < 0 && cargoWeigh > 1) {
      return this.setData({
        'selectedCargo.cargoWeigh': cargoWeigh - 1,
      })
    }
  },
  handleSubmitDisableToggle() {
    const { selectedCargo } = this.data
    const { selectedType, selectedPrice } = selectedCargo

    this.setData({
      disableSubmit: !selectedType || !selectedPrice,
    })
  },
}

Component({
  data: state,
  methods: {
    ...actions,
  },
  attached() {
    const selectedCargo = app.globalData.orderBillInfo.selectedCargo

    if (!selectedCargo.cargoTags || !selectedCargo.cargoTags.length) {
      API_ADPTER.showNavigationBarLoading()
      return fetchCargoTags().then(
        () => {
          API_ADPTER.hideNavigationBarLoading()
          this.initSelectCargo()
        },
        () => {
          API_ADPTER.hideNavigationBarLoading()
        }
      )
    }
    this.initSelectCargo()
  },
})
