import { getLocationPoi } from '../../common/utils/location'
import orderTime from './containers/orderTime'
import { ADDR_INFO } from 'src/common/constants/addr'
import { COUPON_INFO } from '../../common/constants/coupon'
import { ORDER_FEE_INFO } from '../../common/constants/feeInfo'
import {
  getSenderAddrList,
  getReceiverAddrList,
} from '../../common/pages/addrList/api'
import { login, checkLogin } from 'src/common/utils/login'
import {
  calcOrderFee,
  addOrder,
  queryAccountInfo,
  getAdDisplay,
  fetchNearDada,
  fetchAcceptTime,
  fetchCouponMessage,
  getNearestSender,
  getCouponsNum,
  getAvailableCouponsNum,
} from './api'
import { fetchCargoTags } from './components/selectCargo/api'
import { ORDER_BILL_INFO } from './constant'
import track from 'track-mini-program'
import {
  PAY_TYPE_WECHAT,
  PAY_TYPE_BALANCE,
  PAY_TYPE_OTHER,
} from '../../common/constants/payType'
import { navigateTo } from 'src/common/utils/navigate'
import { triggerTask } from 'src/pages/activity/sign/api'
import { API_ADPTER } from 'src/common/adapters/index'

const SELECT_CARGO = {
  senderPoiName: '',
  receiverPoiName: '',
}

let prevUpdateShowSelectCargo = { ...SELECT_CARGO }

const app = getApp()
const data = {
  orderTime: orderTime.state,
  orderBillInfo: {
    ...ORDER_BILL_INFO,
  },
  address: {
    sender: { ...ADDR_INFO },
    receiver: { ...ADDR_INFO },
  },
  isNeedFinishCode: true,
  payType: PAY_TYPE_WECHAT,
  balance: 0,
  canPayByBalance: false,
  orderFeeInfo: {},

  currentOrderType: 'send',
  hasUsedSenderAddr: false,
  hasUsedReceiverAddr: false,
  // 计算运费loading
  isShowCalcLoading: false,
  adDisplay: [],
  showSelectCargo: false,
  showSlideDownBtn: 0,
  scrollIntoViewId: '',
  // 显示附近达达tip
  showNearDadaTip: false,
  // 预计接单时间
  acceptOrderTime: 10,
  nearDadaCnt: 0,
  couponModalList: [],
  haveCouponsNum: -1,
  nearestSenderInfo: {},
  showNearestSenderTip: -1,
  showTooCloseModal: 0,
  showAddMyAppTip: false,
  banner: [],
  showSelectPayType: false,
  scrollTop: 0,
  tips: 0,
  timer: null,
  bannerActiveIndex: 0,
  trackedIndexList: [],
  platform: 'swan',
}

Page({
  noTrack: true,
  // 是否执行过onLoad
  isInitLoad: false,
  name: '首页',

  data: data,
  ...orderTime.actions,

  onLoad(options) {
    if (options.again) {
      this.resetHomeData()
    }
    this.initPlatform()
    // webUrl跳转逻辑待定
    if (options && options.webUrl) {
      wx.navigateTo({
        url: '/common/pages/web/index/index?webUrl=' + options.webUrl,
      })

      return
    }

    this.isInitLoad = true
  },
  onShow() {
    const pages = getCurrentPages()
    let options = pages[pages.length - 1].options
    if (options && options.taskId) {
      triggerTask({
        taskId: options.taskId,
        appType: 'DADA',
      })
    }
    this.initLogin()
    this.isInitLoad = false
    track.setExtParams({ page_type: '帮我送' })
  },
  onShareAppMessage() {
    return {
      title: '推荐你使用「达达」，同城帮取帮送1小时速达',
      path: '/pages/index/index?channel=share_home',
      imageUrl: 'https://fe.imdada.cn/bwm/0.0.1/images/home-share.jpg',
    }
  },
  initLogin() {
    // 登录
    login(app, false)
      .then(data => {
        this.noTrack = false
        // 登录成功，获取是否存在常用地址
        if (!this.data.hasUsedSenderAddr) {
          track.manuallyTrack({
            clickId: 'ExposureCommonAddress',
            clickPar: { type: 'send' },
          })
          getSenderAddrList({ isCount: 1, pageNum: 1, pageSize: 1 }).then(
            content => {
              if (content && content.list.length) {
                this.setData({ hasUsedSenderAddr: true })
              }
            }
          )
        }
        if (!this.data.hasUsedReceiverAddr) {
          track.manuallyTrack({
            clickId: 'ExposureCommonAddress',
            clickPar: { type: 'receive' },
          })
          getReceiverAddrList({ isCount: 1, pageNum: 1, pageSize: 1 }).then(
            content => {
              if (content && content.list.length) {
                this.setData({ hasUsedReceiverAddr: true })
              }
            }
          )
        }
        this.getBalanceInfo()
        this.fetchCouponMessage()

        if (!app.globalData.commonAddress.location.city) {
          // 获取当前定位信息
          getLocationPoi().then(() => {
            this.getAdDisplay()
            this.initPageShow()
          })
        } else {
          this.getAdDisplay()
          this.initPageShow()
        }

        fetchCargoTags()
        track.manuallyTrack()
      })
      .catch(() => {
        if (!app.globalData.commonAddress.location.city) {
          // 获取当前定位信息
          getLocationPoi().then(() => {
            this.initPageShow()
          })
        } else {
          this.initPageShow()
        }
        this.noTrack = false
        track.manuallyTrack()
      })
  },
  initPageShow() {
    const { orderBillInfo, commonAddress, currentOrderType } = app.globalData
    const {
      sender,
      receiver,
      location: { lat, lng },
    } = commonAddress
    const updateData = {
      orderBillInfo: {
        ...orderBillInfo,
      },
      address: {
        sender,
        receiver,
      },
      currentOrderType,
    }

    this.setData(updateData)
    this.handleOrderFeeUpdate()
    this.updateShowSelectCargo()
    this.updateTips()
    this.getNearestSender({ lat, lng })
    this.getCouponsNum()
    this.updateShowAddMyApp()
    this.updateOrderTimeDisabled()
  },
  initPlatform() {
    this.setData({ platform: app.globalData.platform })
  },
  // 获取账户余额
  getBalanceInfo() {
    queryAccountInfo().then(res => {
      this.setData({
        balance: res.balance,
      })
    })
  },
  // 更改支付方式为余额支付
  changePayTypeBalance() {
    const { canPayByBalance } = this.data

    if (!canPayByBalance) return

    this.setData({
      payType: PAY_TYPE_BALANCE,
    })
  },
  // 更改支付方式为微信支付
  changePayTypeWechat() {
    this.setData({
      payType: PAY_TYPE_WECHAT,
    })
  },
  // 更改支付方式为其他-h5收银台支付
  changePayTypeOther() {
    this.setData({
      payType: PAY_TYPE_OTHER,
    })
  },
  // 自动选择支付方式
  autoChangePayType() {
    const { orderFeeInfo, balance } = this.data

    if (orderFeeInfo.needPay <= balance) {
      this.setData({
        canPayByBalance: true,
      })
      this.changePayTypeBalance()
    } else {
      this.setData({
        canPayByBalance: false,
      })
      if (this.data.platform === 'weapp') {
        this.changePayTypeWechat()
      } else {
        this.changePayTypeOther()
      }
    }
  },
  // 更新订单费用
  handleOrderFeeUpdate() {
    const {
      orderBillInfo,
      address: { sender, receiver },
    } = this.data

    if (
      !orderBillInfo.selectedCargo.selectedType ||
      !sender.id ||
      !receiver.id
    ) {
      return
    }

    this.setData({
      isShowCalcLoading: true,
    })

    calcOrderFee(this.data)
      .then(data => {
        if (data.dynamicPrice) {
          track.manuallyTrack({ clickId: 'ExposureImprovePrice' })
        }
        this.setData({
          isShowCalcLoading: false,
          orderFeeInfo: data,
        })
        this.autoChangePayType()
        app.globalData.commonOrderFeeInfo.feeInfo = data
        app.globalData.commonCoupon.activeCouponId =
          data.freightCouponId === null ? '' : data.freightCouponId

        app.globalData.commonCoupon = {
          ...app.globalData.commonCoupon,
          from: 'orderCoupon',
          totalPrice: data.totalPrice,
          orderScene: this.data.currentOrderType === 'send' ? 1 : 2,
          activeCouponId: data.freightCouponId,
          distance: data.distance,
        }
        this.getCouponsNum()
      })
      .catch(() => {
        this.setData({
          isShowCalcLoading: false,
        })
      })
  },
  handleAddOrder() {
    const { orderBillInfo } = app.globalData
    const { showTooCloseModal, orderFeeInfo } = this.data

    if (!this.checkSenderReceiverInfo()) return

    if (!orderBillInfo.selectedCargo.selectedType) {
      track.manuallyTrack({
        clickId: 'ClickChooseGoodsInfo',
        clickPar: { type: '下单弹出' },
      })
      this.toggleShowSelectCargo()

      return
    }

    if (orderFeeInfo.distance <= 100 && showTooCloseModal === 0) {
      track.manuallyTrack({ clickId: 'ExposureAddressNear' })
      this.setData({ showTooCloseModal: 1 })

      return
    }
    const {
      orderBillInfo: {
        selectedCargo: { selectedTypeName, selectedPriceName, cargoWeigh },
      },
      orderTime: { selected },
    } = this.data

    track.manuallyTrack({
      clickId: 'ClickPayNow',
      clickPar: {
        goods_type: selectedTypeName,
        goods_price: selectedPriceName,
        goods_weight: cargoWeigh,
        deliver_time: selected.desc,
      },
    })
    if (this.data.canPayByBalance) {
      this.toggleShowSelectPayType()
    } else {
      this.handleOrderCreate()
    }
  },
  // 生成订单
  handleOrderCreate() {
    this.setData({
      isShowCalcLoading: true,
    })
    const {
      orderBillInfo: {
        selectedCargo: { selectedTypeName, selectedPriceName, cargoWeigh },
      },
      orderTime: { selected },
      payType,
    } = this.data

    track.manuallyTrack({
      clickId: 'ClickToPay',
      clickPar: {
        goods_type: selectedTypeName,
        goods_price: selectedPriceName,
        goods_weight: cargoWeigh,
        deliver_time: selected.desc,
        pay_type: payType === PAY_TYPE_WECHAT ? '微信' : '余额',
      },
    })
    addOrder(this.data)
      .then(data => {
        prevUpdateShowSelectCargo = { ...SELECT_CARGO }
        this.setData({ isShowCalcLoading: false })
        this.data.showSelectPayType && this.toggleShowSelectPayType()
        const { feeInfo } = app.globalData.commonOrderFeeInfo

        // 跳转详情页面
        app.globalData.orderDetailInfo.activeOrderId = data.orderId
        app.globalData.orderDetailInfo.autoPay =
          !!feeInfo.needPay && this.data.payType !== PAY_TYPE_BALANCE
        app.globalData.orderDetailInfo.isBwm = false
        this.resetHomeData()
        API_ADPTER.navigateTo({
          url: `/common/pages/orderDetail/index`,
        })
      })
      .catch(() => {
        this.setData({ isShowCalcLoading: false })
        this.data.showSelectPayType && this.toggleShowSelectPayType()
      })
  },
  // 跳转的编辑发货地址
  handleSenderEdit() {
    if (
      !checkLogin({
        mode: 'getLoginStatusAndJump',
        url: `/common/pages/login/index`,
      })
    ) { return }

    app.globalData.commonAddress = {
      ...app.globalData.commonAddress,
      edit: {
        ...this.data.address.sender,
      },
      type: 'sender',
      title:
        this.data.currentOrderType === 'send' ? '填写发货信息' : '填写收货信息',
      from: 'pages/index/index',
    }

    API_ADPTER.navigateTo({
      url: '/common/pages/addrEdit/index',
    })
  },
  // 选择常用发货地址
  handleSenderSelect() {
    track.manuallyTrack({
      clickId: 'ClickCommonAddress',
      clickPar: { type: 'send' },
    })
    app.globalData.commonAddress = {
      ...app.globalData.commonAddress,
      type: 'sender',
      from: 'pages/index/index',
    }

    API_ADPTER.navigateTo({
      url: '/common/pages/addrList/index',
    })
  },
  // 跳转的编辑收货地址
  handleReceiverEdit() {
    if (
      !checkLogin({
        mode: 'getLoginStatusAndJump',
        url: `/common/pages/login/index`,
      })
    ) { return }

    app.globalData.commonAddress = {
      ...app.globalData.commonAddress,
      edit: {
        ...this.data.address.receiver,
      },
      title:
        this.data.currentOrderType === 'send' ? '填写收货信息' : '填写取货信息',
      type: 'receiver',
      from: 'pages/index/index',
    }

    API_ADPTER.navigateTo({
      url: '/common/pages/addrEdit/index',
    })
  },
  // 选择收货地址
  handleReceiverSelect() {
    track.manuallyTrack({
      clickId: 'ClickCommonAddress',
      clickPar: { type: 'receive' },
    })
    app.globalData.commonAddress = {
      ...app.globalData.commonAddress,
      type: 'receiver',
      from: 'pages/index/index',
    }

    API_ADPTER.navigateTo({
      url: '/common/pages/addrList/index',
    })
  },
  // 加小费
  payTip(e) {
    const isSub = e.target.dataset.type === 'sub'

    if (isSub && this.data.tips === 0) {
      return
    }
    if (!this.checkSenderReceiverInfo()) {
      return
    }

    this.setData({
      tips: isSub ? this.data.tips - 1 : this.data.tips + 1,
    })

    clearTimeout(this.data.timer)

    this.setData({
      timer: setTimeout(() => {
        this.handleOrderFeeUpdate()
      }, 300),
    })
  },
  // 切换是否需要收货码
  handleFinishCodeToggle() {
    const { isNeedFinishCode } = this.data

    track.manuallyTrack({
      clickId: 'ClickReceiveCode',
      clickPar: { status: !isNeedFinishCode ? 'open' : 'close' },
    })
    this.setData({
      isNeedFinishCode: !isNeedFinishCode,
    })

    this.handleOrderFeeUpdate()
  },
  // 收货码须知
  handleShowSignRecevieTip() {
    API_ADPTER.navigateTo({
      url: '/pages/receiveCode/index',
    })
  },
  // 填写备注
  handleRemarkSkip() {
    if (this.checkSenderReceiverInfo()) {
      API_ADPTER.navigateTo({
        url: '/pages/remark/index',
      })
    }
  },
  // 跳转到运费详情
  handleDeliveryFeeSkip() {
    const { sender, receiver } = this.data.address
    const type = this.data.currentOrderType === 'send' ? 'bws' : 'bwq'
    const routeInfo =
      type === 'bwq'
        ? {
          type,
          startLat: receiver.lat,
          startLng: receiver.lng,
          endLat: sender.lat,
          endLng: sender.lng,
        }
        : {
          type,
          startLat: sender.lat,
          startLng: sender.lng,
          endLat: receiver.lat,
          endLng: receiver.lng,
        }

    app.globalData.commonOrderFeeInfo.routeInfo = routeInfo
    API_ADPTER.navigateTo({
      url: '/common/pages/feeInfo/index',
    })
  },
  // 选取优惠券
  handleCouponSkip() {
    const { orderFeeInfo, currentOrderType } = this.data

    if (!orderFeeInfo.totalPrice) {
      const { orderBillInfo } = this.data

      if (!this.checkSenderReceiverInfo()) return

      if (!orderBillInfo.selectedCargo.selectedType) {
        API_ADPTER.showToast({
          title: '请先填写物品信息',
          icon: 'none',
        })

        return
      }

      return
    }

    app.globalData.commonCoupon = {
      ...app.globalData.commonCoupon,
      from: 'orderCoupon',
      totalPrice: orderFeeInfo.totalPrice,
      orderScene: currentOrderType === 'send' ? 1 : 2,
      activeCouponId: orderFeeInfo.freightCouponId,
      distance: orderFeeInfo.distance,
    }

    API_ADPTER.navigateTo({
      url: '/common/pages/couponList/index',
    })
  },
  // 重置首页数据
  resetHomeData() {
    this.setData({
      isNeedFinishCode: true,
      orderFeeInfo: {},
      orderTime: { ...orderTime.state },
      orderBillInfo: {
        ...ORDER_BILL_INFO,
      },
      showNearestSenderTip: -1,
      showTooCloseModal: 0,
      showSlideDownBtn: 0,
      haveCouponsNum: -1,
      tips: 0,
      currentOrderType: 'send',
    })
    app.globalData.orderBillInfo = {
      ...ORDER_BILL_INFO,
    }
    app.globalData.commonOrderFeeInfo = {
      ...ORDER_FEE_INFO,
    }
    app.globalData.commonCoupon = {
      ...COUPON_INFO,
    }
    app.globalData.commonAddress.sender = {
      ...ADDR_INFO,
    }
    app.globalData.commonAddress.receiver = {
      ...ADDR_INFO,
    }
    app.globalData.prev.senderPoiName = ''
    app.globalData.prev.receiverPoiName = ''
    app.globalData.prev.freightCouponId = ''
    app.globalData.currentOrderType = 'send'
  },
  handleTabToggle(e) {
    const type = e.currentTarget.dataset.type
    const map = {
      send: '帮我送',
      accept: '帮我取',
      bwm: '帮我买',
    }
    track.manuallyTrack({
      clickId: 'ClickHomeChangeStatus',
      clickPar: { status: map[type] },
    })

    if (type === 'bwm') {
      API_ADPTER.navigateToMiniProgram({ appId: 'wxcccbedbea4d570e2' })

      return
    }
    if (type === this.data.currentOrderType) return

    track.setExtParams({ page_type: map[type] })
    this.setData({ currentOrderType: type })
    app.globalData.currentOrderType = type
    this.initPageShow()
  },
  handleBannerChange(e) {
    const { banner, trackedIndexList } = this.data
    const index = e.detail.current
    let tracked = false

    trackedIndexList.map(item => {
      if (item === index) { tracked = true }
    })
    this.setData({ bannerActiveIndex: index })
    if (!tracked) {
      track.manuallyTrack({
        clickId: 'Exposure',
        clickPar: {
          res_type: `banner_${banner.length}`,
          res_unit: index + 1,
          url: banner[index].link,
        },
      })
      trackedIndexList.push(index)
      this.setData({
        trackedIndexList: trackedIndexList,
      })
    }
  },
  getAdDisplay() {
    const adCode = app.globalData.commonAddress.location.adCode

    getAdDisplay({ adCode, p: 26 }).then(res => {
      this.setData({ banner: res })
    })
  },
  toggleShowSelectCargo() {
    this.setData({
      showSelectCargo: !this.data.showSelectCargo,
    })
  },
  toggleShowSelectPayType() {
    this.setData({ showSelectPayType: !this.data.showSelectPayType })
  },
  updateCargoInfo() {
    const { orderBillInfo } = app.globalData

    this.toggleShowSelectCargo()
    this.setData({ orderBillInfo })
    this.updateShowSlideDownBtn()
    this.handleOrderFeeUpdate()
  },
  handleContainerScroll(e) {
    const { scrollTop } = e.detail

    this.setData({ scrollTop })

    if (scrollTop > 50) {
      this.setData({ showSlideDownBtn: 0 })
    }
  },
  updateShowSlideDownBtn() {
    const {
      address: { sender, receiver },
      orderBillInfo: { selectedCargo },
      showSlideDownBtn,
      scrollTop,
    } = this.data

    if (
      showSlideDownBtn === 0 &&
      scrollTop <= 10 &&
      sender.id &&
      receiver.id &&
      selectedCargo
    ) {
      this.setData({ showSlideDownBtn: 1 })
    }
  },
  autoScroll() {
    track.manuallyTrack({ clickId: 'ClickMoreService' })
    this.setData({
      scrollIntoViewId: 'footer-bar-placeholder',
      showSlideDownBtn: 0,
    })
  },
  updateShowSelectCargo() {
    const {
      address: { sender, receiver },
      orderBillInfo: { selectedCargo },
    } = this.data

    const {
      senderPoiName: prevSenderPoiName,
      receiverPoiName: prevReceiverPoiName,
    } = prevUpdateShowSelectCargo

    const that = this

    if (
      !selectedCargo.selectedType &&
      sender.id &&
      receiver.id &&
      (sender.poiName !== prevSenderPoiName ||
        receiver.poiName !== prevReceiverPoiName)
    ) {
      track.manuallyTrack({
        clickId: 'ClickChooseGoodsInfo',
        clickPar: { type: '自动弹出' },
      })
      prevUpdateShowSelectCargo.senderPoiName = sender.poiName
      prevUpdateShowSelectCargo.receiverPoiName = receiver.poiName

      setTimeout(function () {
        that.toggleShowSelectCargo()
      }, 300)
    }
  },
  // 点击我的
  handleMyClick() {
    API_ADPTER.navigateTo({
      url: '/common/pages/mine/index?isBwm=false',
    })
  },
  // 点击订单列表
  handleOrderListClick() {
    API_ADPTER.navigateTo({
      url: '/common/pages/orderList/index?isBwm=false',
    })
  },
  getTimeAndNearDada({ lat, lng, adCode }) {
    // 1. 获取预估接单时间
    fetchAcceptTime({ lng, lat, adCode })
      .then(res => {
        this.setData({
          acceptOrderTime: (res.acceptSec / 60).toFixed(0),
        })
      })
      .catch(e => {
        this.setData({
          tipText: '当前城市暂未开通',
        })
      })
    // 2. 调用达达api获取周围骑士经纬度
    fetchNearDada({ lng, lat }).then(res => {
      this.setData({ nearDadaCnt: res.length })
    })
  },
  // 更新附近达达信息
  updateTips() {
    const {
      address: { sender, receiver },
      currentOrderType,
    } = this.data

    if (currentOrderType === 'send' && sender.id) {
      const { lat, lng, adCode } = sender
      this.setData({ showNearDadaTip: true })
      this.trackNearDadaTipExposure()
      this.getTimeAndNearDada({ lat, lng, adCode })

      return
    }
    if (currentOrderType === 'accept' && receiver.id) {
      const { lat, lng, adCode } = receiver
      this.setData({ showNearDadaTip: true })
      this.trackNearDadaTipExposure()
      this.getTimeAndNearDada({ lat, lng, adCode })

      return
    }
    this.setData({ showNearDadaTip: false })
  },
  handleNearDadaTipClick() {
    track.manuallyTrack({
      clickId: 'ClickExposure',
      clickPar: { res_type: 'notic' },
    })
  },
  trackNearDadaTipExposure() {
    track.manuallyTrack({
      clickId: 'Exposure',
      clickPar: { res_type: 'notic' },
    })
  },
  updateOrderTimeDisabled() {
    const {
      address: { sender, receiver },
    } = this.data
    this.setData({ 'orderTime.disabled': !sender.id || !receiver.id })
  },
  fetchCouponMessage() {
    fetchCouponMessage().then(res =>
      this.setData({
        couponModalList: res,
      })
    )
  },
  getNearestSender(params) {
    if (!API_ADPTER.getStorageSync('TOKEN')) return
    const {
      showNearestSenderTip,
      address: { sender },
    } = this.data

    if (sender.id) {
      this.setData({
        nearestSenderInfo: {},
        showNearestSenderTip: 0,
      })

      return
    }

    if (showNearestSenderTip === -1) {
      getNearestSender(params)
        .then(senderInfo => {
          if (senderInfo.id) {
            this.setData({
              nearestSenderInfo: senderInfo,
              showNearestSenderTip: 1,
            })
          }
        })
        .catch(e => console.log(e))
    }
  },
  hideNearestSenderTip() {
    track.manuallyTrack({ clickId: 'ClickCloseRecAddress' })
    this.setData({ showNearestSenderTip: 0 })
  },
  useNearestSenderInfo() {
    track.manuallyTrack({ clickId: 'ClickChooseRecAddress' })
    this.hideNearestSenderTip()
    this.setData({ 'address.sender': this.data.nearestSenderInfo })
    app.globalData.commonAddress.sender = { ...this.data.nearestSenderInfo }
    this.updateTips()
  },
  handleContinueAddOrder() {
    track.manuallyTrack({ clickId: 'ClickCreateOrderContinue' })
    this.setData({ showTooCloseModal: 0 })
    if (this.data.canPayByBalance) {
      this.toggleShowSelectPayType()
    } else {
      this.handleOrderCreate()
    }
  },
  handleCheckOrder() {
    track.manuallyTrack({ clickId: 'ClickCheckOrderInfo' })
    this.setData({ showTooCloseModal: 0 })
  },
  getCouponsNum() {
    if (!API_ADPTER.getStorageSync('TOKEN')) return
    const {
      haveCouponsNum,
      orderFeeInfo: { totalPrice },
    } = this.data

    if (totalPrice) {
      getAvailableCouponsNum().then(res => {
        this.setData({ haveCouponsNum: res })
      })
    } else {
      if (haveCouponsNum === -1) {
        getCouponsNum().then(res => {
          this.setData({ haveCouponsNum: res })
        })
      }
    }
  },
  handleCouponModalOk() {
    this.setData({ couponModalList: [] })
  },
  updateShowAddMyApp() {
    const alreayShowAddTip = API_ADPTER.getStorageSync(
      'ALREADY_SHOW_ADD_MY_APP_TIP'
    )

    if (alreayShowAddTip) return

    this.setData({ showAddMyAppTip: true })
    API_ADPTER.setStorageSync('ALREADY_SHOW_ADD_MY_APP_TIP', true)
  },
  hideAddMyAppTip() {
    this.setData({ showAddMyAppTip: false })
  },
  handleBannerItemClick(e) {
    const {
      itemInfo: { link },
      itemIndex,
    } = e.currentTarget.dataset
    const { banner } = this.data

    track.manuallyTrack({
      clickId: 'ClickExposure',
      clickPar: {
        res_type: `banner_${banner.length}`,
        res_unit: itemIndex + 1,
        url: link,
      },
    })

    if (!API_ADPTER.getStorageSync('TOKEN')) {
      navigateTo({ url: `/common/pages/login/index` })

      return
    }
    if (link[0] === '/') {
      API_ADPTER.navigateTo({ url: link })
    } else {
      const res = JSON.parse(link)

      API_ADPTER.navigateToMiniProgram(res)
    }
  },
  handleShowSelectCargo() {
    if (!this.checkSenderReceiverInfo()) return
    track.manuallyTrack({
      clickId: 'ClickChooseGoodsInfo',
      clickPar: { type: '手动选择' },
    })
    this.toggleShowSelectCargo()
  },
  checkSenderReceiverInfo() {
    const {
      address: { sender, receiver },
    } = this.data

    if (!sender.id || !receiver.id) {
      track.manuallyTrack({ clickId: 'ExposureWriteAddress' })
      API_ADPTER.showToast({
        title: '请先填写地址信息',
        icon: 'none',
      })
      this.setData({ scrollIntoViewId: 'header-bar-placeholder' })

      return false
    }
    return true
  },
  hideSelectCargo() {
    const {
      orderBillInfo: {
        selectedCargo: {
          selectedTypeName = '',
          selectedPriceName = '',
          cargoWeigh = '',
        },
      },
    } = this.data
    track.manuallyTrack({
      clickId: 'ClickCloseGoodsInfo',
      clickPar: {
        goods_type: selectedTypeName,
        goods_price: selectedPriceName,
        goods_weight: cargoWeigh,
      },
    })
    this.toggleShowSelectCargo()
  },
  goInsurance() {
    if (this.checkSenderReceiverInfo()) {
      API_ADPTER.navigateTo({ url: '/pages/insurance/index' })
    }
  },
})
